# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ...dyn.text.accessible_endnote_view import AccessibleEndnoteView as AccessibleEndnoteView
with suppress(ImportError):
    from ...dyn.text.accessible_footnote_view import AccessibleFootnoteView as AccessibleFootnoteView
with suppress(ImportError):
    from ...dyn.text.accessible_header_footer_view import AccessibleHeaderFooterView as AccessibleHeaderFooterView
with suppress(ImportError):
    from ...dyn.text.accessible_page_view import AccessiblePageView as AccessiblePageView
with suppress(ImportError):
    from ...dyn.text.accessible_paragraph_view import AccessibleParagraphView as AccessibleParagraphView
with suppress(ImportError):
    from ...dyn.text.accessible_text_document_page_view import AccessibleTextDocumentPageView as AccessibleTextDocumentPageView
with suppress(ImportError):
    from ...dyn.text.accessible_text_document_view import AccessibleTextDocumentView as AccessibleTextDocumentView
with suppress(ImportError):
    from ...dyn.text.accessible_text_embedded_object import AccessibleTextEmbeddedObject as AccessibleTextEmbeddedObject
with suppress(ImportError):
    from ...dyn.text.accessible_text_frame_view import AccessibleTextFrameView as AccessibleTextFrameView
with suppress(ImportError):
    from ...dyn.text.accessible_text_graphic_object import AccessibleTextGraphicObject as AccessibleTextGraphicObject
with suppress(ImportError):
    from ...dyn.text.author_display_format import AuthorDisplayFormat as AuthorDisplayFormat
with suppress(ImportError):
    from ...dyn.text.author_display_format import AuthorDisplayFormatEnum as AuthorDisplayFormatEnum
with suppress(ImportError):
    from ...dyn.text.auto_text_container import AutoTextContainer as AutoTextContainer
with suppress(ImportError):
    from ...dyn.text.auto_text_entry import AutoTextEntry as AutoTextEntry
with suppress(ImportError):
    from ...dyn.text.auto_text_group import AutoTextGroup as AutoTextGroup
with suppress(ImportError):
    from ...dyn.text.base_frame import BaseFrame as BaseFrame
with suppress(ImportError):
    from ...dyn.text.base_frame_properties import BaseFrameProperties as BaseFrameProperties
with suppress(ImportError):
    from ...dyn.text.base_index import BaseIndex as BaseIndex
with suppress(ImportError):
    from ...dyn.text.base_index_mark import BaseIndexMark as BaseIndexMark
with suppress(ImportError):
    from ...dyn.text.bibliography import Bibliography as Bibliography
with suppress(ImportError):
    from ...dyn.text.bibliography_data_field import BibliographyDataField as BibliographyDataField
with suppress(ImportError):
    from ...dyn.text.bibliography_data_field import BibliographyDataFieldEnum as BibliographyDataFieldEnum
with suppress(ImportError):
    from ...dyn.text.bibliography_data_type import BibliographyDataType as BibliographyDataType
with suppress(ImportError):
    from ...dyn.text.bibliography_data_type import BibliographyDataTypeEnum as BibliographyDataTypeEnum
with suppress(ImportError):
    from ...dyn.text.bookmark import Bookmark as Bookmark
with suppress(ImportError):
    from ...dyn.text.bookmarks import Bookmarks as Bookmarks
with suppress(ImportError):
    from ...dyn.text.cell import Cell as Cell
with suppress(ImportError):
    from ...dyn.text.cell_properties import CellProperties as CellProperties
with suppress(ImportError):
    from ...dyn.text.cell_range import CellRange as CellRange
with suppress(ImportError):
    from ...dyn.text.chained_text_frame import ChainedTextFrame as ChainedTextFrame
with suppress(ImportError):
    from ...dyn.text.chapter_format import ChapterFormat as ChapterFormat
with suppress(ImportError):
    from ...dyn.text.chapter_format import ChapterFormatEnum as ChapterFormatEnum
with suppress(ImportError):
    from ...dyn.text.chapter_numbering_rule import ChapterNumberingRule as ChapterNumberingRule
with suppress(ImportError):
    from ...dyn.text.character_compression_type import CharacterCompressionType as CharacterCompressionType
with suppress(ImportError):
    from ...dyn.text.character_compression_type import CharacterCompressionTypeEnum as CharacterCompressionTypeEnum
with suppress(ImportError):
    from ...dyn.text.column_separator_style import ColumnSeparatorStyle as ColumnSeparatorStyle
with suppress(ImportError):
    from ...dyn.text.column_separator_style import ColumnSeparatorStyleEnum as ColumnSeparatorStyleEnum
with suppress(ImportError):
    from ...dyn.text.content_index import ContentIndex as ContentIndex
with suppress(ImportError):
    from ...dyn.text.content_index_mark import ContentIndexMark as ContentIndexMark
with suppress(ImportError):
    from ...dyn.text.control_character import ControlCharacter as ControlCharacter
with suppress(ImportError):
    from ...dyn.text.control_character import ControlCharacterEnum as ControlCharacterEnum
with suppress(ImportError):
    from ...dyn.text.date_display_format import DateDisplayFormat as DateDisplayFormat
with suppress(ImportError):
    from ...dyn.text.date_display_format import DateDisplayFormatEnum as DateDisplayFormatEnum
with suppress(ImportError):
    from ...dyn.text.default_numbering_provider import DefaultNumberingProvider as DefaultNumberingProvider
with suppress(ImportError):
    from ...dyn.text.defaults import Defaults as Defaults
with suppress(ImportError):
    from ...dyn.text.dependent_text_field import DependentTextField as DependentTextField
with suppress(ImportError):
    from ...dyn.text.document_index import DocumentIndex as DocumentIndex
with suppress(ImportError):
    from ...dyn.text.document_index_level_format import DocumentIndexLevelFormat as DocumentIndexLevelFormat
with suppress(ImportError):
    from ...dyn.text.document_index_mark import DocumentIndexMark as DocumentIndexMark
with suppress(ImportError):
    from ...dyn.text.document_index_mark_asian import DocumentIndexMarkAsian as DocumentIndexMarkAsian
with suppress(ImportError):
    from ...dyn.text.document_index_paragraph_styles import DocumentIndexParagraphStyles as DocumentIndexParagraphStyles
with suppress(ImportError):
    from ...dyn.text.document_indexes import DocumentIndexes as DocumentIndexes
with suppress(ImportError):
    from ...dyn.text.document_settings import DocumentSettings as DocumentSettings
with suppress(ImportError):
    from ...dyn.text.document_statistic import DocumentStatistic as DocumentStatistic
with suppress(ImportError):
    from ...dyn.text.document_statistic import DocumentStatisticEnum as DocumentStatisticEnum
with suppress(ImportError):
    from ...dyn.text.endnote import Endnote as Endnote
with suppress(ImportError):
    from ...dyn.text.endnote_settings import EndnoteSettings as EndnoteSettings
with suppress(ImportError):
    from ...dyn.text.filename_display_format import FilenameDisplayFormat as FilenameDisplayFormat
with suppress(ImportError):
    from ...dyn.text.filename_display_format import FilenameDisplayFormatEnum as FilenameDisplayFormatEnum
with suppress(ImportError):
    from ...dyn.text.font_emphasis import FontEmphasis as FontEmphasis
with suppress(ImportError):
    from ...dyn.text.font_emphasis import FontEmphasisEnum as FontEmphasisEnum
with suppress(ImportError):
    from ...dyn.text.font_relief import FontRelief as FontRelief
with suppress(ImportError):
    from ...dyn.text.font_relief import FontReliefEnum as FontReliefEnum
with suppress(ImportError):
    from ...dyn.text.footnote import Footnote as Footnote
with suppress(ImportError):
    from ...dyn.text.footnote_numbering import FootnoteNumbering as FootnoteNumbering
with suppress(ImportError):
    from ...dyn.text.footnote_numbering import FootnoteNumberingEnum as FootnoteNumberingEnum
with suppress(ImportError):
    from ...dyn.text.footnote_settings import FootnoteSettings as FootnoteSettings
with suppress(ImportError):
    from ...dyn.text.footnotes import Footnotes as Footnotes
with suppress(ImportError):
    from ...dyn.text.generic_text_document import GenericTextDocument as GenericTextDocument
with suppress(ImportError):
    from ...dyn.text.global_document import GlobalDocument as GlobalDocument
with suppress(ImportError):
    from ...dyn.text.global_settings import GlobalSettings as GlobalSettings
with suppress(ImportError):
    from ...dyn.text.graphic_crop import GraphicCrop as GraphicCrop
with suppress(ImportError):
    from ...dyn.text.hori_orientation import HoriOrientation as HoriOrientation
with suppress(ImportError):
    from ...dyn.text.hori_orientation import HoriOrientationEnum as HoriOrientationEnum
with suppress(ImportError):
    from ...dyn.text.hori_orientation_format import HoriOrientationFormat as HoriOrientationFormat
with suppress(ImportError):
    from ...dyn.text.horizontal_adjust import HorizontalAdjust as HorizontalAdjust
with suppress(ImportError):
    from ...dyn.text.illustrations_index import IllustrationsIndex as IllustrationsIndex
with suppress(ImportError):
    from ...dyn.text.in_content_metadata import InContentMetadata as InContentMetadata
with suppress(ImportError):
    from ...dyn.text.invalid_text_content_exception import InvalidTextContentException as InvalidTextContentException
with suppress(ImportError):
    from ...dyn.text.label_follow import LabelFollow as LabelFollow
with suppress(ImportError):
    from ...dyn.text.label_follow import LabelFollowEnum as LabelFollowEnum
with suppress(ImportError):
    from ...dyn.text.line_numbering_properties import LineNumberingProperties as LineNumberingProperties
with suppress(ImportError):
    from ...dyn.text.mail_merge import MailMerge as MailMerge
with suppress(ImportError):
    from ...dyn.text.mail_merge_event import MailMergeEvent as MailMergeEvent
with suppress(ImportError):
    from ...dyn.text.mail_merge_type import MailMergeType as MailMergeType
with suppress(ImportError):
    from ...dyn.text.mail_merge_type import MailMergeTypeEnum as MailMergeTypeEnum
with suppress(ImportError):
    from ...dyn.text.module_dispatcher import ModuleDispatcher as ModuleDispatcher
with suppress(ImportError):
    from ...dyn.text.note_print_mode import NotePrintMode as NotePrintMode
with suppress(ImportError):
    from ...dyn.text.numbering_level import NumberingLevel as NumberingLevel
with suppress(ImportError):
    from ...dyn.text.numbering_rules import NumberingRules as NumberingRules
with suppress(ImportError):
    from ...dyn.text.numbering_style import NumberingStyle as NumberingStyle
with suppress(ImportError):
    from ...dyn.text.object_index import ObjectIndex as ObjectIndex
with suppress(ImportError):
    from ...dyn.text.page_footnote_info import PageFootnoteInfo as PageFootnoteInfo
with suppress(ImportError):
    from ...dyn.text.page_number_type import PageNumberType as PageNumberType
with suppress(ImportError):
    from ...dyn.text.page_print_settings import PagePrintSettings as PagePrintSettings
with suppress(ImportError):
    from ...dyn.text.paragraph import Paragraph as Paragraph
with suppress(ImportError):
    from ...dyn.text.paragraph_enumeration import ParagraphEnumeration as ParagraphEnumeration
with suppress(ImportError):
    from ...dyn.text.paragraph_vert_align import ParagraphVertAlign as ParagraphVertAlign
with suppress(ImportError):
    from ...dyn.text.paragraph_vert_align import ParagraphVertAlignEnum as ParagraphVertAlignEnum
with suppress(ImportError):
    from ...dyn.text.placeholder_type import PlaceholderType as PlaceholderType
with suppress(ImportError):
    from ...dyn.text.placeholder_type import PlaceholderTypeEnum as PlaceholderTypeEnum
with suppress(ImportError):
    from ...dyn.text.position_and_space_mode import PositionAndSpaceMode as PositionAndSpaceMode
with suppress(ImportError):
    from ...dyn.text.position_and_space_mode import PositionAndSpaceModeEnum as PositionAndSpaceModeEnum
with suppress(ImportError):
    from ...dyn.text.position_layout_dir import PositionLayoutDir as PositionLayoutDir
with suppress(ImportError):
    from ...dyn.text.position_layout_dir import PositionLayoutDirEnum as PositionLayoutDirEnum
with suppress(ImportError):
    from ...dyn.text.print_settings import PrintSettings as PrintSettings
with suppress(ImportError):
    from ...dyn.text.redline_portion import RedlinePortion as RedlinePortion
with suppress(ImportError):
    from ...dyn.text.reference_field_part import ReferenceFieldPart as ReferenceFieldPart
with suppress(ImportError):
    from ...dyn.text.reference_field_part import ReferenceFieldPartEnum as ReferenceFieldPartEnum
with suppress(ImportError):
    from ...dyn.text.reference_field_source import ReferenceFieldSource as ReferenceFieldSource
with suppress(ImportError):
    from ...dyn.text.reference_field_source import ReferenceFieldSourceEnum as ReferenceFieldSourceEnum
with suppress(ImportError):
    from ...dyn.text.reference_mark import ReferenceMark as ReferenceMark
with suppress(ImportError):
    from ...dyn.text.reference_marks import ReferenceMarks as ReferenceMarks
with suppress(ImportError):
    from ...dyn.text.rel_orientation import RelOrientation as RelOrientation
with suppress(ImportError):
    from ...dyn.text.rel_orientation import RelOrientationEnum as RelOrientationEnum
with suppress(ImportError):
    from ...dyn.text.ruby_adjust import RubyAdjust as RubyAdjust
with suppress(ImportError):
    from ...dyn.text.ruby_position import RubyPosition as RubyPosition
with suppress(ImportError):
    from ...dyn.text.ruby_position import RubyPositionEnum as RubyPositionEnum
with suppress(ImportError):
    from ...dyn.text.section_file_link import SectionFileLink as SectionFileLink
with suppress(ImportError):
    from ...dyn.text.set_variable_type import SetVariableType as SetVariableType
with suppress(ImportError):
    from ...dyn.text.set_variable_type import SetVariableTypeEnum as SetVariableTypeEnum
with suppress(ImportError):
    from ...dyn.text.shape import Shape as Shape
with suppress(ImportError):
    from ...dyn.text.size_type import SizeType as SizeType
with suppress(ImportError):
    from ...dyn.text.size_type import SizeTypeEnum as SizeTypeEnum
with suppress(ImportError):
    from ...dyn.text.table_column_separator import TableColumnSeparator as TableColumnSeparator
with suppress(ImportError):
    from ...dyn.text.table_columns import TableColumns as TableColumns
with suppress(ImportError):
    from ...dyn.text.table_index import TableIndex as TableIndex
with suppress(ImportError):
    from ...dyn.text.table_rows import TableRows as TableRows
with suppress(ImportError):
    from ...dyn.text.template_display_format import TemplateDisplayFormat as TemplateDisplayFormat
with suppress(ImportError):
    from ...dyn.text.template_display_format import TemplateDisplayFormatEnum as TemplateDisplayFormatEnum
with suppress(ImportError):
    from ...dyn.text.text import Text as Text
with suppress(ImportError):
    from ...dyn.text.text_column import TextColumn as TextColumn
with suppress(ImportError):
    from ...dyn.text.text_column_sequence import TextColumnSequence as TextColumnSequence
with suppress(ImportError):
    from ...dyn.text.text_columns import TextColumns as TextColumns
with suppress(ImportError):
    from ...dyn.text.text_content import TextContent as TextContent
with suppress(ImportError):
    from ...dyn.text.text_content_anchor_type import TextContentAnchorType as TextContentAnchorType
with suppress(ImportError):
    from ...dyn.text.text_content_collection import TextContentCollection as TextContentCollection
with suppress(ImportError):
    from ...dyn.text.text_cursor import TextCursor as TextCursor
with suppress(ImportError):
    from ...dyn.text.text_document import TextDocument as TextDocument
with suppress(ImportError):
    from ...dyn.text.text_document_view import TextDocumentView as TextDocumentView
with suppress(ImportError):
    from ...dyn.text.text_embedded_object import TextEmbeddedObject as TextEmbeddedObject
with suppress(ImportError):
    from ...dyn.text.text_embedded_objects import TextEmbeddedObjects as TextEmbeddedObjects
with suppress(ImportError):
    from ...dyn.text.text_field import TextField as TextField
with suppress(ImportError):
    from ...dyn.text.text_field_enumeration import TextFieldEnumeration as TextFieldEnumeration
with suppress(ImportError):
    from ...dyn.text.text_field_master import TextFieldMaster as TextFieldMaster
with suppress(ImportError):
    from ...dyn.text.text_field_masters import TextFieldMasters as TextFieldMasters
with suppress(ImportError):
    from ...dyn.text.text_fields import TextFields as TextFields
with suppress(ImportError):
    from ...dyn.text.text_frame import TextFrame as TextFrame
with suppress(ImportError):
    from ...dyn.text.text_frames import TextFrames as TextFrames
with suppress(ImportError):
    from ...dyn.text.text_graphic_object import TextGraphicObject as TextGraphicObject
with suppress(ImportError):
    from ...dyn.text.text_graphic_objects import TextGraphicObjects as TextGraphicObjects
with suppress(ImportError):
    from ...dyn.text.text_grid_mode import TextGridMode as TextGridMode
with suppress(ImportError):
    from ...dyn.text.text_grid_mode import TextGridModeEnum as TextGridModeEnum
with suppress(ImportError):
    from ...dyn.text.text_layout_cursor import TextLayoutCursor as TextLayoutCursor
with suppress(ImportError):
    from ...dyn.text.text_markup_descriptor import TextMarkupDescriptor as TextMarkupDescriptor
with suppress(ImportError):
    from ...dyn.text.text_markup_type import TextMarkupType as TextMarkupType
with suppress(ImportError):
    from ...dyn.text.text_markup_type import TextMarkupTypeEnum as TextMarkupTypeEnum
with suppress(ImportError):
    from ...dyn.text.text_page_style import TextPageStyle as TextPageStyle
with suppress(ImportError):
    from ...dyn.text.text_portion import TextPortion as TextPortion
with suppress(ImportError):
    from ...dyn.text.text_portion_enumeration import TextPortionEnumeration as TextPortionEnumeration
with suppress(ImportError):
    from ...dyn.text.text_position import TextPosition as TextPosition
with suppress(ImportError):
    from ...dyn.text.text_range import TextRange as TextRange
with suppress(ImportError):
    from ...dyn.text.text_range_content_properties import TextRangeContentProperties as TextRangeContentProperties
with suppress(ImportError):
    from ...dyn.text.text_range_selection import TextRangeSelection as TextRangeSelection
with suppress(ImportError):
    from ...dyn.text.text_ranges import TextRanges as TextRanges
with suppress(ImportError):
    from ...dyn.text.text_section import TextSection as TextSection
with suppress(ImportError):
    from ...dyn.text.text_sections import TextSections as TextSections
with suppress(ImportError):
    from ...dyn.text.text_sort_descriptor import TextSortDescriptor as TextSortDescriptor
with suppress(ImportError):
    from ...dyn.text.text_sort_descriptor2 import TextSortDescriptor2 as TextSortDescriptor2
with suppress(ImportError):
    from ...dyn.text.text_sortable import TextSortable as TextSortable
with suppress(ImportError):
    from ...dyn.text.text_table import TextTable as TextTable
with suppress(ImportError):
    from ...dyn.text.text_table_cursor import TextTableCursor as TextTableCursor
with suppress(ImportError):
    from ...dyn.text.text_table_row import TextTableRow as TextTableRow
with suppress(ImportError):
    from ...dyn.text.text_tables import TextTables as TextTables
with suppress(ImportError):
    from ...dyn.text.text_view_cursor import TextViewCursor as TextViewCursor
with suppress(ImportError):
    from ...dyn.text.time_display_format import TimeDisplayFormat as TimeDisplayFormat
with suppress(ImportError):
    from ...dyn.text.time_display_format import TimeDisplayFormatEnum as TimeDisplayFormatEnum
with suppress(ImportError):
    from ...dyn.text.user_data_part import UserDataPart as UserDataPart
with suppress(ImportError):
    from ...dyn.text.user_data_part import UserDataPartEnum as UserDataPartEnum
with suppress(ImportError):
    from ...dyn.text.user_defined_index import UserDefinedIndex as UserDefinedIndex
with suppress(ImportError):
    from ...dyn.text.user_field_format import UserFieldFormat as UserFieldFormat
with suppress(ImportError):
    from ...dyn.text.user_field_format import UserFieldFormatEnum as UserFieldFormatEnum
with suppress(ImportError):
    from ...dyn.text.user_index import UserIndex as UserIndex
with suppress(ImportError):
    from ...dyn.text.user_index_mark import UserIndexMark as UserIndexMark
with suppress(ImportError):
    from ...dyn.text.vert_orientation import VertOrientation as VertOrientation
with suppress(ImportError):
    from ...dyn.text.vert_orientation import VertOrientationEnum as VertOrientationEnum
with suppress(ImportError):
    from ...dyn.text.vert_orientation_format import VertOrientationFormat as VertOrientationFormat
with suppress(ImportError):
    from ...dyn.text.view_settings import ViewSettings as ViewSettings
with suppress(ImportError):
    from ...dyn.text.web_document import WebDocument as WebDocument
with suppress(ImportError):
    from ...dyn.text.wrap_influence_on_position import WrapInfluenceOnPosition as WrapInfluenceOnPosition
with suppress(ImportError):
    from ...dyn.text.wrap_influence_on_position import WrapInfluenceOnPositionEnum as WrapInfluenceOnPositionEnum
with suppress(ImportError):
    from ...dyn.text.wrap_text_mode import WrapTextMode as WrapTextMode
with suppress(ImportError):
    from ...dyn.text.writing_mode import WritingMode as WritingMode
with suppress(ImportError):
    from ...dyn.text.writing_mode2 import WritingMode2 as WritingMode2
with suppress(ImportError):
    from ...dyn.text.writing_mode2 import WritingMode2Enum as WritingMode2Enum
with suppress(ImportError):
    from ...dyn.text.x_auto_text_container import XAutoTextContainer as XAutoTextContainer
with suppress(ImportError):
    from ...dyn.text.x_auto_text_container2 import XAutoTextContainer2 as XAutoTextContainer2
with suppress(ImportError):
    from ...dyn.text.x_auto_text_entry import XAutoTextEntry as XAutoTextEntry
with suppress(ImportError):
    from ...dyn.text.x_auto_text_group import XAutoTextGroup as XAutoTextGroup
with suppress(ImportError):
    from ...dyn.text.x_bookmark_insert_tool import XBookmarkInsertTool as XBookmarkInsertTool
with suppress(ImportError):
    from ...dyn.text.x_bookmarks_supplier import XBookmarksSupplier as XBookmarksSupplier
with suppress(ImportError):
    from ...dyn.text.x_chapter_numbering_supplier import XChapterNumberingSupplier as XChapterNumberingSupplier
with suppress(ImportError):
    from ...dyn.text.x_default_numbering_provider import XDefaultNumberingProvider as XDefaultNumberingProvider
with suppress(ImportError):
    from ...dyn.text.x_dependent_text_field import XDependentTextField as XDependentTextField
with suppress(ImportError):
    from ...dyn.text.x_document_index import XDocumentIndex as XDocumentIndex
with suppress(ImportError):
    from ...dyn.text.x_document_index_mark import XDocumentIndexMark as XDocumentIndexMark
with suppress(ImportError):
    from ...dyn.text.x_document_indexes_supplier import XDocumentIndexesSupplier as XDocumentIndexesSupplier
with suppress(ImportError):
    from ...dyn.text.x_endnotes_settings_supplier import XEndnotesSettingsSupplier as XEndnotesSettingsSupplier
with suppress(ImportError):
    from ...dyn.text.x_endnotes_supplier import XEndnotesSupplier as XEndnotesSupplier
with suppress(ImportError):
    from ...dyn.text.x_flat_paragraph import XFlatParagraph as XFlatParagraph
with suppress(ImportError):
    from ...dyn.text.x_flat_paragraph_iterator import XFlatParagraphIterator as XFlatParagraphIterator
with suppress(ImportError):
    from ...dyn.text.x_flat_paragraph_iterator_provider import XFlatParagraphIteratorProvider as XFlatParagraphIteratorProvider
with suppress(ImportError):
    from ...dyn.text.x_footnote import XFootnote as XFootnote
with suppress(ImportError):
    from ...dyn.text.x_footnotes_settings_supplier import XFootnotesSettingsSupplier as XFootnotesSettingsSupplier
with suppress(ImportError):
    from ...dyn.text.x_footnotes_supplier import XFootnotesSupplier as XFootnotesSupplier
with suppress(ImportError):
    from ...dyn.text.x_form_field import XFormField as XFormField
with suppress(ImportError):
    from ...dyn.text.x_line_numbering_properties import XLineNumberingProperties as XLineNumberingProperties
with suppress(ImportError):
    from ...dyn.text.x_mail_merge_broadcaster import XMailMergeBroadcaster as XMailMergeBroadcaster
with suppress(ImportError):
    from ...dyn.text.x_mail_merge_listener import XMailMergeListener as XMailMergeListener
with suppress(ImportError):
    from ...dyn.text.x_marking_access import XMarkingAccess as XMarkingAccess
with suppress(ImportError):
    from ...dyn.text.x_multi_text_markup import XMultiTextMarkup as XMultiTextMarkup
with suppress(ImportError):
    from ...dyn.text.x_numbering_formatter import XNumberingFormatter as XNumberingFormatter
with suppress(ImportError):
    from ...dyn.text.x_numbering_rules_supplier import XNumberingRulesSupplier as XNumberingRulesSupplier
with suppress(ImportError):
    from ...dyn.text.x_numbering_type_info import XNumberingTypeInfo as XNumberingTypeInfo
with suppress(ImportError):
    from ...dyn.text.x_page_cursor import XPageCursor as XPageCursor
with suppress(ImportError):
    from ...dyn.text.x_page_printable import XPagePrintable as XPagePrintable
with suppress(ImportError):
    from ...dyn.text.x_paragraph_append import XParagraphAppend as XParagraphAppend
with suppress(ImportError):
    from ...dyn.text.x_paragraph_cursor import XParagraphCursor as XParagraphCursor
with suppress(ImportError):
    from ...dyn.text.x_paste_broadcaster import XPasteBroadcaster as XPasteBroadcaster
with suppress(ImportError):
    from ...dyn.text.x_paste_listener import XPasteListener as XPasteListener
with suppress(ImportError):
    from ...dyn.text.x_redline import XRedline as XRedline
with suppress(ImportError):
    from ...dyn.text.x_reference_marks_supplier import XReferenceMarksSupplier as XReferenceMarksSupplier
with suppress(ImportError):
    from ...dyn.text.x_relative_text_content_insert import XRelativeTextContentInsert as XRelativeTextContentInsert
with suppress(ImportError):
    from ...dyn.text.x_relative_text_content_remove import XRelativeTextContentRemove as XRelativeTextContentRemove
with suppress(ImportError):
    from ...dyn.text.x_ruby_selection import XRubySelection as XRubySelection
with suppress(ImportError):
    from ...dyn.text.x_sentence_cursor import XSentenceCursor as XSentenceCursor
with suppress(ImportError):
    from ...dyn.text.x_simple_text import XSimpleText as XSimpleText
with suppress(ImportError):
    from ...dyn.text.x_text import XText as XText
with suppress(ImportError):
    from ...dyn.text.x_text_append import XTextAppend as XTextAppend
with suppress(ImportError):
    from ...dyn.text.x_text_append_and_convert import XTextAppendAndConvert as XTextAppendAndConvert
with suppress(ImportError):
    from ...dyn.text.x_text_columns import XTextColumns as XTextColumns
with suppress(ImportError):
    from ...dyn.text.x_text_content import XTextContent as XTextContent
with suppress(ImportError):
    from ...dyn.text.x_text_content_append import XTextContentAppend as XTextContentAppend
with suppress(ImportError):
    from ...dyn.text.x_text_convert import XTextConvert as XTextConvert
with suppress(ImportError):
    from ...dyn.text.x_text_copy import XTextCopy as XTextCopy
with suppress(ImportError):
    from ...dyn.text.x_text_cursor import XTextCursor as XTextCursor
with suppress(ImportError):
    from ...dyn.text.x_text_document import XTextDocument as XTextDocument
with suppress(ImportError):
    from ...dyn.text.x_text_embedded_objects_supplier import XTextEmbeddedObjectsSupplier as XTextEmbeddedObjectsSupplier
with suppress(ImportError):
    from ...dyn.text.x_text_field import XTextField as XTextField
with suppress(ImportError):
    from ...dyn.text.x_text_fields_supplier import XTextFieldsSupplier as XTextFieldsSupplier
with suppress(ImportError):
    from ...dyn.text.x_text_frame import XTextFrame as XTextFrame
with suppress(ImportError):
    from ...dyn.text.x_text_frames_supplier import XTextFramesSupplier as XTextFramesSupplier
with suppress(ImportError):
    from ...dyn.text.x_text_graphic_objects_supplier import XTextGraphicObjectsSupplier as XTextGraphicObjectsSupplier
with suppress(ImportError):
    from ...dyn.text.x_text_markup import XTextMarkup as XTextMarkup
with suppress(ImportError):
    from ...dyn.text.x_text_portion_append import XTextPortionAppend as XTextPortionAppend
with suppress(ImportError):
    from ...dyn.text.x_text_range import XTextRange as XTextRange
with suppress(ImportError):
    from ...dyn.text.x_text_range_compare import XTextRangeCompare as XTextRangeCompare
with suppress(ImportError):
    from ...dyn.text.x_text_range_mover import XTextRangeMover as XTextRangeMover
with suppress(ImportError):
    from ...dyn.text.x_text_section import XTextSection as XTextSection
with suppress(ImportError):
    from ...dyn.text.x_text_sections_supplier import XTextSectionsSupplier as XTextSectionsSupplier
with suppress(ImportError):
    from ...dyn.text.x_text_shapes_supplier import XTextShapesSupplier as XTextShapesSupplier
with suppress(ImportError):
    from ...dyn.text.x_text_table import XTextTable as XTextTable
with suppress(ImportError):
    from ...dyn.text.x_text_table_cursor import XTextTableCursor as XTextTableCursor
with suppress(ImportError):
    from ...dyn.text.x_text_tables_supplier import XTextTablesSupplier as XTextTablesSupplier
with suppress(ImportError):
    from ...dyn.text.x_text_view_cursor import XTextViewCursor as XTextViewCursor
with suppress(ImportError):
    from ...dyn.text.x_text_view_cursor_supplier import XTextViewCursorSupplier as XTextViewCursorSupplier
with suppress(ImportError):
    from ...dyn.text.x_text_view_text_range_supplier import XTextViewTextRangeSupplier as XTextViewTextRangeSupplier
with suppress(ImportError):
    from ...dyn.text.x_word_cursor import XWordCursor as XWordCursor



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..container.x_named import XNamed as XNamed_a6520b08
from .x_cell_range_referrer import XCellRangeReferrer as XCellRangeReferrer_91c0e23
from .x_database_range import XDatabaseRange as XDatabaseRange_d37b0c7b
from ..util.x_refreshable import XRefreshable as XRefreshable_b0d60b81
if typing.TYPE_CHECKING:
    from ..table.cell_range_address import CellRangeAddress as CellRangeAddress_ec450d43

class DatabaseRange(XPropertySet_bc180bfa, XNamed_a6520b08, XCellRangeReferrer_91c0e23, XDatabaseRange_d37b0c7b, XRefreshable_b0d60b81):
    """
    Service Class

    represents a database range in a spreadsheet document.
    
    A database range is a name for a cell range that also stores filtering, sorting, subtotal and data import settings and options.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API DatabaseRange <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.DatabaseRange'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def AutoFilter(self) -> bool:
        """
        specifies whether the AutoFilter is enabled or not.
        
        **since**
        
            OOo 1.1.2
        """
        ...

    @abstractproperty
    def ContainsHeader(self) -> bool:
        """
        specifies whether this range includes a top row of headers.
        
        **since**
        
            LibreOffice 5.0
        """
        ...

    @abstractproperty
    def FilterCriteriaSource(self) -> CellRangeAddress_ec450d43:
        """
        specifies the range where the filter can find the filter criteria.
        
        This is only used if SheetFilterDescriptor.UseFilterCriteriaSource is TRUE.
        
        **since**
        
            OOo 1.1.2
        """
        ...

    @abstractproperty
    def FromSelection(self) -> bool:
        """
        specifies whether the imported data is only a selection of the database.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def KeepFormats(self) -> bool:
        """
        if this property is set, cell formats are extended when the size of the range is changed by an update operation.
        """
        ...

    @abstractproperty
    def MoveCells(self) -> bool:
        """
        if this property is set, columns or rows are inserted or deleted when the size of the range is changed by an update operation.
        """
        ...

    @abstractproperty
    def RefreshPeriod(self) -> int:
        """
        specifies the time between two refresh actions in seconds.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def StripData(self) -> bool:
        """
        if this property is set, the cell contents within the database range are left out when the document is saved.
        """
        ...

    @abstractproperty
    def TokenIndex(self) -> int:
        """
        returns the index used to refer to this range in token arrays.
        
        A token describing a database range shall contain the op-code obtained from the FormulaMapGroupSpecialOffset.DB_AREA and this index as data part.
        
        **since**
        
            OOo 3.0
        """
        ...

    @abstractproperty
    def TotalsRow(self) -> bool:
        """
        specifies whether this range includes a bottom row of totals.
        
        **since**
        
            LibreOffice 5.0
        """
        ...

    @abstractproperty
    def UseFilterCriteriaSource(self) -> bool:
        """
        specifies whether the filter criteria should be taken from a CellRange.
        
        **since**
        
            OOo 1.1.2
        """
        ...


__all__ = ['DatabaseRange']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui
from __future__ import annotations
from abc import abstractmethod
from .x_module_ui_configuration_manager2 import XModuleUIConfigurationManager2 as XModuleUIConfigurationManager2_98c61187

class ModuleUIConfigurationManager(XModuleUIConfigurationManager2_98c61187):
    """
    Service Class

    specifies a user interface configuration manager which gives access to user interface configuration data of a module.
    
    A module user interface configuration manager supports two layers of configuration settings data:
    
    **since**
    
        OOo 2.0

    See Also:
        `API ModuleUIConfigurationManager <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ui_1_1ModuleUIConfigurationManager.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui'
    __ooo_full_ns__: str = 'com.sun.star.ui.ModuleUIConfigurationManager'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def createDefault(self, ModuleShortName: str, ModuleIdentifier: str) -> None:
        """
        provides a function to initialize a module user interface configuration manager instance.
        
        A module user interface configuration manager instance needs the following arguments as com.sun.star.beans.PropertyValue to be in a working state:
        
        A non-initialized module user interface configuration manager cannot be used, it is treated as a read-only container.

        Raises:
            com.sun.star.configuration.CorruptedUIConfigurationException: ``CorruptedUIConfigurationException``
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...

__all__ = ['ModuleUIConfigurationManager']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.embed
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_encryption_protected_source2 import XEncryptionProtectedSource2 as XEncryptionProtectedSource2_9eb411d5
if typing.TYPE_CHECKING:
    from ..beans.named_value import NamedValue as NamedValue_a37a0af3

class XEncryptionProtectedStorage(XEncryptionProtectedSource2_9eb411d5):
    """
    This interface allows to set a password for an object.
    
    **since**
    
        OOo 3.4

    See Also:
        `API XEncryptionProtectedStorage <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1embed_1_1XEncryptionProtectedStorage.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.embed'
    __ooo_full_ns__: str = 'com.sun.star.embed.XEncryptionProtectedStorage'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.embed.XEncryptionProtectedStorage'

    @abstractmethod
    def getEncryptionAlgorithms(self) -> typing.Tuple[NamedValue_a37a0af3, ...]:
        """
        allows to get the encryption algorithms of the object.
        """
        ...
    @abstractmethod
    def setEncryptionAlgorithms(self, aAlgorithms: typing.Tuple[NamedValue_a37a0af3, ...]) -> None:
        """
        allows to set the encryption algorithms for the object.
        
        The algorithms will of course be used only for streams that have been marked to be encrypted. If no stream in the storage is marked to be encrypted, the algorithms-related information may have no effect to the result package.
        
        The following values could be part of the provided sequence:

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def setGpgProperties(self, aProps: typing.Tuple[typing.Tuple[NamedValue_a37a0af3, ...], ...]) -> None:
        """
        set OpenPGP-specific encryption properties
        
        When provided, switch ODF package encryption to OpenPGP.
        
        For each recipient, add one sequence of named values, each of the same structure. The following values could be part of that provided sequence:
        
        **since**
        
            LibreOffice 6.0

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XEncryptionProtectedStorage']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.task
from __future__ import annotations
from .x_password_container2 import XPasswordContainer2 as XPasswordContainer2_ce70e3b

class PasswordContainer(XPasswordContainer2_ce70e3b):
    """
    Service Class

    this service is kind of storage that allows to store passwords and to retrieve already stored.
    
    A password can be stored for the session period or persistently. The persistent way is only possible if configuration allows to use storage. It stores passwords encrypted with a super password. An interaction is used to ask a user for a super password. To allow such an interaction, an object that implements XInteractionHandler interface should be provided. For this purpose InteractionHandler service can be used.
    
    In case no interaction handler is provided all passwords are stored for the session period. In case an interaction handler is provided, but the super password interaction does not return super password ( for any reason ), NoMasterException exception is thrown to let user use non-persistent way explicitly.

    See Also:
        `API PasswordContainer <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1task_1_1PasswordContainer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.task'
    __ooo_full_ns__: str = 'com.sun.star.task.PasswordContainer'
    __ooo_type_name__: str = 'service'


__all__ = ['PasswordContainer']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet.opencl
from __future__ import annotations
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .open_cl_platform import OpenCLPlatform as OpenCLPlatform_36540f36

class XOpenCLSelection(XInterface_8f010a43):
    """

    See Also:
        `API XOpenCLSelection <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1opencl_1_1XOpenCLSelection.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet.opencl'
    __ooo_full_ns__: str = 'com.sun.star.sheet.opencl.XOpenCLSelection'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sheet.opencl.XOpenCLSelection'

    @abstractmethod
    def disableAutomaticDeviceSelection(self) -> None:
        """
        Disables automatic OpenCL Device Selection.
        """
        ...
    @abstractmethod
    def disableOpcodeSubsetTest(self) -> None:
        """
        """
        ...
    @abstractmethod
    def enableAutomaticDeviceSelection(self, force: bool) -> None:
        """
        Enables automatic OpenCL Device Selection.
        """
        ...
    @abstractmethod
    def enableOpcodeSubsetTest(self) -> None:
        """
        """
        ...
    @abstractmethod
    def enableOpenCL(self, enable: bool) -> None:
        """
        Enables or disables use of OpenCL for calculations.
        
        When using this API to enable OpenCL the configuration parameters are set to their built-in default values, not ones read from the installation of user-specific configuration.
        """
        ...
    @abstractmethod
    def getDeviceID(self) -> int:
        """
        returns the index of the currently selected device.
        
        This is an index into the sequence of devices in the OpenCLPLatform object the device is part of in the current instance of LibreOffice (and not some a priori defined identifier for a specific model of device accessed through a specific platform).
        """
        ...
    @abstractmethod
    def getFormulaCellNumberLimit(self) -> int:
        """
        """
        ...
    @abstractmethod
    def getOpenCLPlatforms(self) -> typing.Tuple[OpenCLPlatform_36540f36, ...]:
        """
        lists all OpenCL devices and platforms
        """
        ...
    @abstractmethod
    def getPlatformID(self) -> int:
        """
        returns the index of the platform of the currently selected device.
        
        This is an index into the sequence that getOpenCLPlatforms returns in the current instance of LibreOffice (and not some a priori defined identifier for an OpenCL platform).
        """
        ...
    @abstractmethod
    def isOpcodeSubsetTested(self) -> bool:
        """
        """
        ...
    @abstractmethod
    def isOpenCLEnabled(self) -> bool:
        """
        Returns true if calculation with OpenCL is enabled (at all).
        
        The actual use of OpenCL for a formula is also affected by the configuration settings specifying whether OpenCL is used for all opcodes or just for a subset, and the deny- and allowlists of OpenCL implementations that are in use.
        """
        ...
    @abstractmethod
    def selectOpenCLDevice(self, platform: int, device: int) -> None:
        """
        Select the OpenCL device with the given platform and device number.
        
        The platform number corresponds to an index into the sequence returned by getOpenCLPlatforms, and the device number corresponds to an index into the sequence of devices in that platform.
        """
        ...
    @abstractmethod
    def setFormulaCellNumberLimit(self, number: int) -> None:
        """
        """
        ...

__all__ = ['XOpenCLSelection']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ucb
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class ListActionType(metaclass=UnoConstMeta, type_name="com.sun.star.ucb.ListActionType", name_space="com.sun.star.ucb"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.ucb.ListActionType``"""
        pass

    class ListActionTypeEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.ucb.ListActionType", name_space="com.sun.star.ucb"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.ucb.ListActionType`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.ucb import ListActionType as ListActionType
    else:
        # keep document generators happy
        from ...lo.ucb.list_action_type import ListActionType as ListActionType

    class ListActionTypeEnum(IntEnum):
        """
        Enum of Const Class ListActionType

        These values are used to specify the type of change happened to a list.
        
        A change happened is sent from an XDynamicResultSet as ListAction to a XDynamicResultSetListener.
        
        The values are contained in ListAction.ListActionType.
        """
        WELCOME = ListActionType.WELCOME
        """
        First notification to a single listener for purpose of initialization.
        
        This type of notification is required to be sent first and only once to a new listener.
        
        The member ListAction.ActionInfo is required to contain a struct WelcomeDynamicResultSetStruct. This struct contains two com.sun.star.sdbc.XResultSets (old and new). During and after the notification only the new set is valid for access. But the listener is required to remind both com.sun.star.sdbc.XResultSets as he will not get another chance to get them again.
        
        The members ListAction.Count and ListAction.Position are not used.
        """
        INSERTED = ListActionType.INSERTED
        """
        One or more rows were inserted into the list.
        
        This action is related to ContentAction.INSERTED.
        
        The members ListAction.Count and ListAction.Position contain the position and count of newly inserted rows. If the count is greater than one, the inserted rows have to be one after the other.
        
        ListAction.ActionInfo could contain something but this is not required. For example, it could contain the properties of the new rows (i.e. for remote optimizing), but this is not required nor unrestrictedly recommended.
        """
        REMOVED = ListActionType.REMOVED
        """
        One or more rows were removed from the list.
        
        This action is related to ContentAction.REMOVED.
        
        The members ListAction.Count and ListAction.Position contain the position and count of the removed rows. If the count is greater than one, the removed rows have to be one after the other.
        
        The member ListAction.ListActionType is not used.
        """
        CLEARED = ListActionType.CLEARED
        """
        The whole list was destroyed and independently rebuild.
        
        If \"CLEARED\" is sent you don't need to refer to the old ResultSet.
        
        The members ListAction.ListActionType, ListAction.Count and ListAction.Position are ignored.
        """
        MOVED = ListActionType.MOVED
        """
        One or more rows were moved to another position.
        
        The members ListAction.Count and ListAction.Position contain the position and count of the moved rows. If the count is greater than one, the moved rows have to be one after the other.
        
        ListAction.ListActionType is required to contain a \"long\", which gives the shift of position. (i.e. When two rows at position 3 and 4 are moved for a shift \"+1\", they will appear at the positions 4 and 5. In this action is included, that the row on old position 5 now appears on position 3. No other notification is needed, to explain or complete this action).
        """
        PROPERTIES_CHANGED = ListActionType.PROPERTIES_CHANGED
        """
        The properties of one or more rows have changed.
        
        This action is related to a com.sun.star.beans.PropertyChangeEvent.
        
        The members ListAction.Count and ListAction.Position contain the position and count of the rows, whose properties have changed. If the count is greater than one, the rows with modified properties have to be one after the other.
        
        ListAction.ActionInfo could contain something but this is not required. For example, it could contain the new properties (i.e. for remote optimizing), but this is not required nor unrestrictedly recommended.
        """
        COMPLETED = ListActionType.COMPLETED

__all__ = ['ListActionType', 'ListActionTypeEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..beans.property import Property as Property_8f4e0a76
from ..uno.x_interface import XInterface as XInterface_8f010a43


class OpenCommandArgument(object):
    """
    Struct Class

    The argument for commands like \"open\", \"update\", and \"synchronize\".

    See Also:
        `API OpenCommandArgument <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1OpenCommandArgument.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.OpenCommandArgument'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.ucb.OpenCommandArgument'
    """Literal Constant ``com.sun.star.ucb.OpenCommandArgument``"""

    def __init__(self, Properties: typing.Optional[typing.Tuple[Property_8f4e0a76, ...]] = (), Mode: typing.Optional[int] = 0, Priority: typing.Optional[int] = 0, Sink: typing.Optional[XInterface_8f010a43] = None) -> None:
        """
        Constructor

        Arguments:
            Properties (typing.Tuple[Property, ...], optional): Properties value.
            Mode (int, optional): Mode value.
            Priority (int, optional): Priority value.
            Sink (XInterface, optional): Sink value.
        """
        super().__init__()

        if isinstance(Properties, OpenCommandArgument):
            oth: OpenCommandArgument = Properties
            self.Properties = oth.Properties
            self.Mode = oth.Mode
            self.Priority = oth.Priority
            self.Sink = oth.Sink
            return

        kargs = {
            "Properties": Properties,
            "Mode": Mode,
            "Priority": Priority,
            "Sink": Sink,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._properties = kwargs["Properties"]
        self._mode = kwargs["Mode"]
        self._priority = kwargs["Priority"]
        self._sink = kwargs["Sink"]


    @property
    def Properties(self) -> typing.Tuple[Property_8f4e0a76, ...]:
        """
        The properties, for that the values shall be provided by the DynamicResultSet returned by the command).
        """
        return self._properties

    @Properties.setter
    def Properties(self, value: typing.Tuple[Property_8f4e0a76, ...]) -> None:
        self._properties = value

    @property
    def Mode(self) -> int:
        """
        A mode.
        
        The value can be one of the OpenMode constants.
        """
        return self._mode

    @Mode.setter
    def Mode(self, value: int) -> None:
        self._mode = value

    @property
    def Priority(self) -> int:
        """
        The command's priority, in the range 0 (highest) to 65535 (lowest).
        """
        return self._priority

    @Priority.setter
    def Priority(self, value: int) -> None:
        self._priority = value

    @property
    def Sink(self) -> XInterface_8f010a43:
        """
        The data sink to write the contents into (supporting either com.sun.star.io.XActiveDataSink, com.sun.star.io.XOutputStream or com.sun.star.io.XActiveDataStreamer).
        
        XActiveDataSink and XOutputStream give the caller read-only access to the contents. XActiveDataStreamer offers both read and write access to the contents.
        
        If an XActiveDataSink is supplied, the implementation of the command needs to provide an implementation of an object implementing the interface com.sun.star.io.XInputStream. It is highly recommended that this object also implements the interface com.sun.star.io.XSeekable, if this can be done without wasting resources (i.e. allocating huge memory buffers). The implementation object has to be supplied to the data sink.
        """
        return self._sink

    @Sink.setter
    def Sink(self, value: XInterface_8f010a43) -> None:
        self._sink = value


__all__ = ['OpenCommandArgument']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.linguistic2
from __future__ import annotations
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from ..lang.locale import Locale as Locale_70d308fa

class XLanguageGuessing(ABC):
    """
    This interface allows to guess the language of a text.
    
    The current set of supported languages is:
    
    **since**
    
        OOo 2.2

    See Also:
        `API XLanguageGuessing <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLanguageGuessing.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.linguistic2'
    __ooo_full_ns__: str = 'com.sun.star.linguistic2.XLanguageGuessing'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.linguistic2.XLanguageGuessing'

    @abstractmethod
    def disableLanguages(self, aLanguages: typing.Tuple[Locale_70d308fa, ...]) -> None:
        """
        allows to explicitly discard some languages from the set of languages possibly returned.
        
        By default all languages are enabled.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def enableLanguages(self, aLanguages: typing.Tuple[Locale_70d308fa, ...]) -> None:
        """
        allows to explicitly re-enable some languages that got previously disabled.
        
        By default all languages are enabled.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def getAvailableLanguages(self) -> typing.Tuple[Locale_70d308fa, ...]:
        """
        returns a list of all supported languages.
        
        This should be the same as the mathematical union of all enabled and disabled languages.
        """
        ...
    @abstractmethod
    def getDisabledLanguages(self) -> typing.Tuple[Locale_70d308fa, ...]:
        """
        returns the list of all disabled languages
        """
        ...
    @abstractmethod
    def getEnabledLanguages(self) -> typing.Tuple[Locale_70d308fa, ...]:
        """
        returns the list of all enabled languages
        """
        ...
    @abstractmethod
    def guessPrimaryLanguage(self, aText: str, nStartPos: int, nLen: int) -> Locale_70d308fa:
        """
        determines the single most probable language of a sub-string.
        
        Please note that because statistical analysis is part of the algorithm the likelihood to get the correct result increases with the length of the sub-string. A word is much less likely guessed correctly compared to a sentence or even a whole paragraph.
        
        Also note that some languages are that \"close\" to each other that it will be quite unlikely to find a difference in them, e.g. English (UK), English (IE) and English (AUS) and most likely English (US) as well. And thus the result may be arbitrary.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XLanguageGuessing']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XOfficeInstallationDirectories(XInterface_8f010a43):
    """
    encapsulates access to the current office installation directory and office user data directory, provides functionality to create URLs containing relocatable (not absolute) references to the current office installation directory and user data directory and vice versa.
    
    This functionality is useful when data containing references to the current office installation directory must be made persistent and re-read later. In many cases, storing the reference directly would destroy the relocatability of an office installation.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XOfficeInstallationDirectories <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XOfficeInstallationDirectories.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.XOfficeInstallationDirectories'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.util.XOfficeInstallationDirectories'

    @abstractmethod
    def getOfficeInstallationDirectoryURL(self) -> str:
        """
        returns the absolute URL containing the directory of the current office installation (for example \"file:///opt/LibreOffice\")
        """
        ...
    @abstractmethod
    def getOfficeUserDataDirectoryURL(self) -> str:
        """
        returns the absolute URL containing the directory where the current office installation expects its user data (for example \"file:///home/kso/.config/libreoffice/4\")
        """
        ...
    @abstractmethod
    def makeAbsoluteURL(self, URL: str) -> str:
        """
        the counterpart of makeRelocatableURL.
        
        If the given URL contains a placeholder for an absolute reference to the current office installation directory or for the office user data directory, that was created using makeRelocatableURL, the respective placeholder will be replaced by an absolute reference to the current office installation directory or office user data directory.
        """
        ...
    @abstractmethod
    def makeRelocatableURL(self, URL: str) -> str:
        """
        calculates a relocatable URL from the given URL.
        
        If the given URL contains an absolute reference to the current office installation directory or office user data directory, this method will replace the absolute reference by an opaque placeholder string. makeRelocatableURL must be used in order to re-replace the placeholder by an absolute reference.
        """
        ...

__all__ = ['XOfficeInstallationDirectories']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class OutgoingMessageState(metaclass=UnoEnumMeta, type_name="com.sun.star.ucb.OutgoingMessageState", name_space="com.sun.star.ucb"):
        """Dynamically created class that represents ``com.sun.star.ucb.OutgoingMessageState`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.ucb.OutgoingMessageState import COMPLETELY_LOCALLY_SENT as OUTGOING_MESSAGE_STATE_COMPLETELY_LOCALLY_SENT
        from com.sun.star.ucb.OutgoingMessageState import CONFIRMED as OUTGOING_MESSAGE_STATE_CONFIRMED
        from com.sun.star.ucb.OutgoingMessageState import EXTERNAL_ERROR as OUTGOING_MESSAGE_STATE_EXTERNAL_ERROR
        from com.sun.star.ucb.OutgoingMessageState import NONRECOVERABLE_LOCAL_ERROR as OUTGOING_MESSAGE_STATE_NONRECOVERABLE_LOCAL_ERROR
        from com.sun.star.ucb.OutgoingMessageState import PARTIALLY_LOCALLY_SENT as OUTGOING_MESSAGE_STATE_PARTIALLY_LOCALLY_SENT
        from com.sun.star.ucb.OutgoingMessageState import RECOVERABLE_LOCAL_ERROR as OUTGOING_MESSAGE_STATE_RECOVERABLE_LOCAL_ERROR
        from com.sun.star.ucb.OutgoingMessageState import WAITING_CONFIRMATION as OUTGOING_MESSAGE_STATE_WAITING_CONFIRMATION
        from com.sun.star.ucb.OutgoingMessageState import WRITTEN as OUTGOING_MESSAGE_STATE_WRITTEN

        class OutgoingMessageState(uno.Enum):
            """
            Enum Class


            See Also:
                `API OutgoingMessageState <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ucb.html#a8dec3ee1933cc93724b3764b124b8cc1>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.ucb.OutgoingMessageState', value)

            __ooo_ns__: str = 'com.sun.star.ucb'
            __ooo_full_ns__: str = 'com.sun.star.ucb.OutgoingMessageState'
            __ooo_type_name__: str = 'enum'

            COMPLETELY_LOCALLY_SENT = OUTGOING_MESSAGE_STATE_COMPLETELY_LOCALLY_SENT
            """
            Message has been sent upstream to all recipients.
            """
            CONFIRMED = OUTGOING_MESSAGE_STATE_CONFIRMED
            """
            Recipient confirmed reading.
            """
            EXTERNAL_ERROR = OUTGOING_MESSAGE_STATE_EXTERNAL_ERROR
            """
            Global fatal error (e.g.

            last member in SMTP chain could not deliver the message).
            """
            NONRECOVERABLE_LOCAL_ERROR = OUTGOING_MESSAGE_STATE_NONRECOVERABLE_LOCAL_ERROR
            """
            Local fatal error (e.g.

            first SMTP server upstream did not accept the message).
            """
            PARTIALLY_LOCALLY_SENT = OUTGOING_MESSAGE_STATE_PARTIALLY_LOCALLY_SENT
            """
            Message has been sent upstream to some recipients.
            """
            RECOVERABLE_LOCAL_ERROR = OUTGOING_MESSAGE_STATE_RECOVERABLE_LOCAL_ERROR
            """
            Local, non-fatal error (e.g.

            network temporarily not available).
            """
            WAITING_CONFIRMATION = OUTGOING_MESSAGE_STATE_WAITING_CONFIRMATION
            """
            Message was sent; we are waiting for confirmation.
            """
            WRITTEN = OUTGOING_MESSAGE_STATE_WRITTEN
            """
            Message has just been placed into the out tray.
            """
    else:
        # keep document generators happy
        from ...lo.ucb.outgoing_message_state import OutgoingMessageState as OutgoingMessageState


__all__ = ['OutgoingMessageState']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractmethod
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from .key_event import KeyEvent as KeyEvent_7a78097f

class XKeyHandler(XEventListener_c7230c4a):
    """
    This key handler is similar to com.sun.star.awt.XKeyListener but allows the consumption of key events.
    
    If a key event is consumed by one handler both the following handlers, with respect to the list of key handlers of the broadcaster, and a following handling by the broadcaster will not take place.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XKeyHandler <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XKeyHandler.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XKeyHandler'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XKeyHandler'

    @abstractmethod
    def keyPressed(self, aEvent: KeyEvent_7a78097f) -> bool:
        """
        This function is called by the broadcaster, an com.sun.star.awt.XExtendedToolkit for instance, after a key has been pressed but before it is released.
        
        The return value decides about whether other handlers will be called and a handling by the broadcaster will take place.
        
        Consume the event if the action performed by the implementation is mutually exclusive with the default action of the broadcaster or, when known, with that of other handlers.
        
        Consuming this event does not prevent the pending key-release event from being broadcasted.
        """
        ...
    @abstractmethod
    def keyReleased(self, aEvent: KeyEvent_7a78097f) -> bool:
        """
        This function is called by the broadcaster, an com.sun.star.awt.XExtendedToolkit for instance, after a key has been pressed and released.
        
        The return value decides about whether other handlers will be called and a handling by the broadcaster will take place.
        
        Consume the event if the action performed by the implementation is mutually exclusive with the default action of the broadcaster or, when known, with that of other handlers.
        """
        ...

__all__ = ['XKeyHandler']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text.textfield
from __future__ import annotations
from abc import abstractproperty
from ..text_field import TextField as TextField_90260a56

class Chapter(TextField_90260a56):
    """
    Service Class

    specifies service of a chapter text field.

    See Also:
        `API Chapter <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1Chapter.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text.textfield'
    __ooo_full_ns__: str = 'com.sun.star.text.textfield.Chapter'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def ChapterFormat(self) -> int:
        """
        determines how the chapter should be displayed as described in com.sun.star.text.ChapterFormat.
        """
        ...

    @abstractproperty
    def Level(self) -> int:
        """
        determines which chapter level should be used.
        
        The highest chapter level has the value 0.
        """
        ...


__all__ = ['Chapter']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..table.cell_range_address import CellRangeAddress as CellRangeAddress_ec450d43
    from com.sun.star.table.TableOrientation import TableOrientationProto

class XSheetOutline(XInterface_8f010a43):
    """
    provides methods to access the outlines of a sheet.

    See Also:
        `API XSheetOutline <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetOutline.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.XSheetOutline'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sheet.XSheetOutline'

    @abstractmethod
    def autoOutline(self, aRange: CellRangeAddress_ec450d43) -> None:
        """
        creates outline groups from formula references in a range.
        """
        ...
    @abstractmethod
    def clearOutline(self) -> None:
        """
        removes all outline groups from the sheet.
        """
        ...
    @abstractmethod
    def group(self, aRange: CellRangeAddress_ec450d43, nOrientation: TableOrientationProto) -> None:
        """
        creates an outline group.
        """
        ...
    @abstractmethod
    def hideDetail(self, aRange: CellRangeAddress_ec450d43) -> None:
        """
        collapses an outline group.
        """
        ...
    @abstractmethod
    def showDetail(self, aRange: CellRangeAddress_ec450d43) -> None:
        """
        reopens an outline group.
        """
        ...
    @abstractmethod
    def showLevel(self, nLevel: int, nOrientation: TableOrientationProto) -> None:
        """
        shows all outlined groups below a specific level.
        """
        ...
    @abstractmethod
    def ungroup(self, aRange: CellRangeAddress_ec450d43, nOrientation: TableOrientationProto) -> None:
        """
        removes outline groups.
        
        In the specified range, all outline groups on the innermost level are removed.
        """
        ...

__all__ = ['XSheetOutline']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n
from __future__ import annotations
import typing
import uno
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..lang.locale import Locale as Locale_70d308fa

class XCollator(XInterface_8f010a43):
    """
    provides locale-sensitive collation algorithms for string comparison.

    See Also:
        `API XCollator <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1i18n_1_1XCollator.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.XCollator'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.i18n.XCollator'

    @abstractmethod
    def compareString(self, aStr1: str, aStr2: str) -> int:
        """
        Compare 2 strings in specific locale and algorithm.
        """
        ...
    @abstractmethod
    def compareSubstring(self, aStr1: str, nOff1: int, nLen1: int, aStr2: str, nOff2: int, nLen2: int) -> int:
        """
        Compare 2 substrings in specific locale and algorithm.
        """
        ...
    @abstractmethod
    def listCollatorAlgorithms(self, aLocale: Locale_70d308fa) -> typing.Tuple[str, ...]:
        """
        List all collator algorithms for a given locale.
        """
        ...
    @abstractmethod
    def listCollatorOptions(self, aAlgorithmName: str) -> uno.ByteSequence:
        """
        List all end user collator options for a given algorithm.
        """
        ...
    @abstractmethod
    def loadCollatorAlgorithm(self, aAlgorithmName: str, aLocale: Locale_70d308fa, nCollatorOptions: int) -> int:
        """
        Load a particular collator algorithm for the locale.
        """
        ...
    @abstractmethod
    def loadCollatorAlgorithmWithEndUserOption(self, aAlgorithmName: str, aLocale: Locale_70d308fa, aCollatorOptions: uno.ByteSequence) -> None:
        """
        Load a collator algorithm with options chosen by end user.
        """
        ...
    @abstractmethod
    def loadDefaultCollator(self, aLocale: Locale_70d308fa, nCollatorOptions: int) -> int:
        """
        Load the collator with default algorithm defined in locale data.
        """
        ...

__all__ = ['XCollator']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class NumberFormatIndex(metaclass=UnoConstMeta, type_name="com.sun.star.i18n.NumberFormatIndex", name_space="com.sun.star.i18n"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.i18n.NumberFormatIndex``"""
        pass

    class NumberFormatIndexEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.i18n.NumberFormatIndex", name_space="com.sun.star.i18n"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.i18n.NumberFormatIndex`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.i18n import NumberFormatIndex as NumberFormatIndex
    else:
        # keep document generators happy
        from ...lo.i18n.number_format_index import NumberFormatIndex as NumberFormatIndex

    class NumberFormatIndexEnum(IntEnum):
        """
        Enum of Const Class NumberFormatIndex

        Do NOT insert any new values! Locale data number format creation must match these values! Number formatter internals must match these values!
        
        Number format indices to be passed as the index argument to XNumberFormatCode.getFormatCode() or com.sun.star.util.XNumberFormatTypes.getFormatIndex().
        
        Each locale can support up to about 5000 arbitrary format codes. But for backward compatibility reasons, each locale MUST support some predefined format codes. These predefined format codes are accessed through indices as the following, and the locale data format code definitions in i18npool/source/localedata/data/*.xml MUST have matching entries in the form
        
        <FormatElement formatindex=\"0\">
        
        (see also FormatElement.formatIndex()).
        
        The index values are also used to define the enum NfIndexTableOffset in file svtools/inc/zforlist.hxx
        
        Note: This index has nothing to do with the index key used internally by the number formatter.
        
        Date formats may have a comment of DIN/EN/ISO, meaning
        
        Some names of date format constants indicate a special behavior of those formats in StarOffice 5.2 or older. Those are:
        """
        NUMBER_START = NumberFormatIndex.NUMBER_START
        """
        Start of simple numerical formats (first format)
        """
        NUMBER_STANDARD = NumberFormatIndex.NUMBER_STANDARD
        """
        The \"General\" standard format formatindex=\"0\".
        """
        NUMBER_INT = NumberFormatIndex.NUMBER_INT
        """
        0 Integer number formatindex=\"1\"
        """
        NUMBER_DEC2 = NumberFormatIndex.NUMBER_DEC2
        """
        0.00 Decimal number with 2 decimals formatindex=\"2\"
        """
        NUMBER_1000INT = NumberFormatIndex.NUMBER_1000INT
        """
        #,##0 Integer number with group separator formatindex=\"3\"
        """
        NUMBER_1000DEC2 = NumberFormatIndex.NUMBER_1000DEC2
        """
        #,##0.00 Decimal number with group separator formatindex=\"4\"
        """
        NUMBER_SYSTEM = NumberFormatIndex.NUMBER_SYSTEM
        """
        #,##0.00 In SO5/Win this format was retrieved from the Regional Settings formatindex=\"5\"
        """
        NUMBER_END = NumberFormatIndex.NUMBER_END
        """
        End of simple numerical formats (last format)
        """
        SCIENTIFIC_START = NumberFormatIndex.SCIENTIFIC_START
        """
        Start of Scientific formats (first format)
        """
        SCIENTIFIC_000E000 = NumberFormatIndex.SCIENTIFIC_000E000
        """
        0.00E+000 Number in scientific notation with exponent in 3 digit placeholders formatindex=\"6\"
        """
        SCIENTIFIC_000E00 = NumberFormatIndex.SCIENTIFIC_000E00
        """
        0.00E+00 Number in scientific notation with exponent in 2 digit placeholders formatindex=\"7\"
        """
        SCIENTIFIC_END = NumberFormatIndex.SCIENTIFIC_END
        """
        End of Scientific formats (last format)
        """
        PERCENT_START = NumberFormatIndex.PERCENT_START
        """
        Start of Percent formats (first format)
        """
        PERCENT_INT = NumberFormatIndex.PERCENT_INT
        """
        0% Percentage format, rounded to integer formatindex=\"8\"
        """
        PERCENT_DEC2 = NumberFormatIndex.PERCENT_DEC2
        """
        0.00% Percentage format, rounded to 2 decimals formatindex=\"9\"
        """
        PERCENT_END = NumberFormatIndex.PERCENT_END
        """
        End of Percent formats (last format)
        """
        FRACTION_START = NumberFormatIndex.FRACTION_START
        """
        Start of Fraction formats (first format)
        """
        FRACTION_1 = NumberFormatIndex.FRACTION_1
        FRACTION_2 = NumberFormatIndex.FRACTION_2
        FRACTION_END = NumberFormatIndex.FRACTION_END
        """
        End of Fraction formats (last format)
        """
        CURRENCY_START = NumberFormatIndex.CURRENCY_START
        """
        Start of Currency formats (first format)
        """
        CURRENCY_1000INT = NumberFormatIndex.CURRENCY_1000INT
        """
        #,##0 DM Integer currency format with group separator formatindex=\"12\"
        """
        CURRENCY_1000DEC2 = NumberFormatIndex.CURRENCY_1000DEC2
        """
        #,##0.00 DM Decimal currency format with group separator formatindex=\"13\"
        """
        CURRENCY_1000INT_RED = NumberFormatIndex.CURRENCY_1000INT_RED
        """
        #,##0 DM Integer currency format with negative in red formatindex=\"14\"
        """
        CURRENCY_1000DEC2_RED = NumberFormatIndex.CURRENCY_1000DEC2_RED
        """
        #,##0.00 DM Decimal currency format with negative in red formatindex=\"15\"
        """
        CURRENCY_1000DEC2_CCC = NumberFormatIndex.CURRENCY_1000DEC2_CCC
        """
        #,##0.00 DEM Currency in ISO-4217 abbreviation format formatindex=\"16\"
        """
        CURRENCY_1000DEC2_DASHED = NumberFormatIndex.CURRENCY_1000DEC2_DASHED
        """
        #,##0.– DM Currency format with dash representing 0 in decimals formatindex=\"17\"
        """
        CURRENCY_END = NumberFormatIndex.CURRENCY_END
        """
        End of Currency formats (last format)
        """
        DATE_START = NumberFormatIndex.DATE_START
        """
        Start of Date formats (first format)
        """
        DATE_SYSTEM_SHORT = NumberFormatIndex.DATE_SYSTEM_SHORT
        """
        08.10.97 see also DATE_SYSTEM_... explanation formatindex=\"18\"
        """
        DATE_SYSTEM_LONG = NumberFormatIndex.DATE_SYSTEM_LONG
        """
        Wednesday, 8.
        
        October 1997 see also DATE_SYSTEM_... explanation formatindex=\"19\"
        """
        DATE_SYS_DDMMYY = NumberFormatIndex.DATE_SYS_DDMMYY
        """
        08.10.97 see also DATE_SYS_... explanation formatindex=\"20\"
        """
        DATE_SYS_DDMMYYYY = NumberFormatIndex.DATE_SYS_DDMMYYYY
        """
        08.10.1997 see also DATE_SYS_...
        
        explanation Note: When editing already existing date data this format is forced in order to always edit the full century. formatindex=\"21\"
        """
        DATE_SYS_DMMMYY = NumberFormatIndex.DATE_SYS_DMMMYY
        DATE_SYS_DMMMYYYY = NumberFormatIndex.DATE_SYS_DMMMYYYY
        DATE_DIN_DMMMYYYY = NumberFormatIndex.DATE_DIN_DMMMYYYY
        DATE_SYS_DMMMMYYYY = NumberFormatIndex.DATE_SYS_DMMMMYYYY
        DATE_DIN_DMMMMYYYY = NumberFormatIndex.DATE_DIN_DMMMMYYYY
        DATE_SYS_NNDMMMYY = NumberFormatIndex.DATE_SYS_NNDMMMYY
        """
        Wed, 8. Oct 97 see also DATE_SYS_... explanation formatindex=\"27\".
        """
        DATE_DEF_NNDDMMMYY = NumberFormatIndex.DATE_DEF_NNDDMMMYY
        """
        Wed 08.Oct 97 see also DATE_DEF_... explanation formatindex=\"28\".
        """
        DATE_SYS_NNDMMMMYYYY = NumberFormatIndex.DATE_SYS_NNDMMMMYYYY
        """
        Wed, 8. October 1997 see also DATE_SYS_... explanation formatindex=\"29\".
        """
        DATE_SYS_NNNNDMMMMYYYY = NumberFormatIndex.DATE_SYS_NNNNDMMMMYYYY
        """
        Wednesday, 8. October 1997 formatindex=\"30\".
        """
        DATE_DIN_MMDD = NumberFormatIndex.DATE_DIN_MMDD
        """
        10-08 DIN/EN formatindex=\"31\"
        """
        DATE_DIN_YYMMDD = NumberFormatIndex.DATE_DIN_YYMMDD
        """
        97-10-08 DIN/EN formatindex=\"32\"
        """
        DATE_DIN_YYYYMMDD = NumberFormatIndex.DATE_DIN_YYYYMMDD
        """
        1997-10-08 DIN/EN/ISO formatindex=\"33\"
        """
        DATE_SYS_MMYY = NumberFormatIndex.DATE_SYS_MMYY
        """
        10.97 see also DATE_SYS_... explanation formatindex=\"34\"
        """
        DATE_SYS_DDMMM = NumberFormatIndex.DATE_SYS_DDMMM
        """
        08.Oct see also DATE_SYS_... explanation formatindex=\"35\"
        """
        DATE_MMMM = NumberFormatIndex.DATE_MMMM
        """
        October formatindex=\"36\".
        """
        DATE_QQJJ = NumberFormatIndex.DATE_QQJJ
        """
        4th quarter 97 formatindex=\"37\"
        """
        DATE_WW = NumberFormatIndex.DATE_WW
        """
        week of year formatindex=\"38\"
        """
        DATE_END = NumberFormatIndex.DATE_END
        """
        End of Date formats (last format)
        """
        TIME_START = NumberFormatIndex.TIME_START
        """
        Start of Time formats (first format)
        """
        TIME_HHMM = NumberFormatIndex.TIME_HHMM
        """
        HH:MM Time format with hour and minute formatindex=\"39\".
        """
        TIME_HHMMSS = NumberFormatIndex.TIME_HHMMSS
        """
        HH:MM:SS Time format with hour, minute and second formatindex=\"40\".
        """
        TIME_HHMMAMPM = NumberFormatIndex.TIME_HHMMAMPM
        """
        HH:MM AM/PM Time format with hour, minute and morning/afternoon notation formatindex=\"41\".
        """
        TIME_HHMMSSAMPM = NumberFormatIndex.TIME_HHMMSSAMPM
        """
        HH:MM:SS AM/PM Time format with hour, minute, second and morning/afternoon notation formatindex=\"42\".
        """
        TIME_HH_MMSS = NumberFormatIndex.TIME_HH_MMSS
        """
        [HH]:MM:SS Time format with amount of hours formatindex=\"43\"
        """
        TIME_MMSS00 = NumberFormatIndex.TIME_MMSS00
        """
        MM:SS,00 Time format with second in fraction formatindex=\"44\".
        """
        TIME_HH_MMSS00 = NumberFormatIndex.TIME_HH_MMSS00
        """
        [HH]:MM:SS,00 Time format with amount of hours and seconds with fraction formatindex=\"45\"
        """
        TIME_END = NumberFormatIndex.TIME_END
        """
        End of Time formats (last format)
        """
        DATETIME_START = NumberFormatIndex.DATETIME_START
        """
        Start of DateTime formats (first format)
        """
        DATETIME_SYSTEM_SHORT_HHMM = NumberFormatIndex.DATETIME_SYSTEM_SHORT_HHMM
        """
        08.10.97 01:23 Date/time format formatindex=\"46\"
        """
        DATETIME_SYS_DDMMYYYY_HHMMSS = NumberFormatIndex.DATETIME_SYS_DDMMYYYY_HHMMSS
        """
        08.10.1997 01:23:45 Date/time format with second Note: When editing already existing date/time data this format is forced in order to always edit the full century.
        
        formatindex=\"47\"
        """
        DATETIME_END = NumberFormatIndex.DATETIME_END
        """
        End of DateTime formats (last format)
        """
        BOOLEAN = NumberFormatIndex.BOOLEAN
        """
        BOOLEAN format.
        """
        TEXT = NumberFormatIndex.TEXT
        """
        Text format.
        """
        INDEX_TABLE_ENTRIES = NumberFormatIndex.INDEX_TABLE_ENTRIES
        """
        count of built-in format codes.
        """

__all__ = ['NumberFormatIndex', 'NumberFormatIndexEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from ..lang.event_object import EventObject as EventObject_a3d70b03
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing
from .list_action import ListAction as ListAction_8df40a3c


class ListEvent(EventObject_a3d70b03):
    """
    Struct Class

    specifies the type of event fired by an XDynamicResultSet

    See Also:
        `API ListEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1ListEvent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.ListEvent'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.ucb.ListEvent'
    """Literal Constant ``com.sun.star.ucb.ListEvent``"""

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = None, Changes: typing.Optional[typing.Tuple[ListAction_8df40a3c, ...]] = ()) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            Changes (typing.Tuple[ListAction, ...], optional): Changes value.
        """

        if isinstance(Source, ListEvent):
            oth: ListEvent = Source
            self.Source = oth.Source
            self.Changes = oth.Changes
            return

        kargs = {
            "Source": Source,
            "Changes": Changes,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._changes = kwargs["Changes"]
        inst_keys = ('Changes',)
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def Changes(self) -> typing.Tuple[ListAction_8df40a3c, ...]:
        """
        If you apply the given ListActions one after the other to the old version of a result set in given order, you will get the positions in the new version.
        """
        return self._changes

    @Changes.setter
    def Changes(self, value: typing.Tuple[ListAction_8df40a3c, ...]) -> None:
        self._changes = value


__all__ = ['ListEvent']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.media
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class ZoomLevel(metaclass=UnoEnumMeta, type_name="com.sun.star.media.ZoomLevel", name_space="com.sun.star.media"):
        """Dynamically created class that represents ``com.sun.star.media.ZoomLevel`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.media.ZoomLevel import FIT_TO_WINDOW as ZOOM_LEVEL_FIT_TO_WINDOW
        from com.sun.star.media.ZoomLevel import FIT_TO_WINDOW_FIXED_ASPECT as ZOOM_LEVEL_FIT_TO_WINDOW_FIXED_ASPECT
        from com.sun.star.media.ZoomLevel import FULLSCREEN as ZOOM_LEVEL_FULLSCREEN
        from com.sun.star.media.ZoomLevel import NOT_AVAILABLE as ZOOM_LEVEL_NOT_AVAILABLE
        from com.sun.star.media.ZoomLevel import ORIGINAL as ZOOM_LEVEL_ORIGINAL
        from com.sun.star.media.ZoomLevel import ZOOM_1_TO_2 as ZOOM_LEVEL_ZOOM_1_TO_2
        from com.sun.star.media.ZoomLevel import ZOOM_1_TO_4 as ZOOM_LEVEL_ZOOM_1_TO_4
        from com.sun.star.media.ZoomLevel import ZOOM_2_TO_1 as ZOOM_LEVEL_ZOOM_2_TO_1
        from com.sun.star.media.ZoomLevel import ZOOM_4_TO_1 as ZOOM_LEVEL_ZOOM_4_TO_1

        class ZoomLevel(uno.Enum):
            """
            Enum Class

            ENUM ZoomLevel

            See Also:
                `API ZoomLevel <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1media.html#aa2569917c2883c1d1c0c0ee02e671ac6>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.media.ZoomLevel', value)

            __ooo_ns__: str = 'com.sun.star.media'
            __ooo_full_ns__: str = 'com.sun.star.media.ZoomLevel'
            __ooo_type_name__: str = 'enum'

            FIT_TO_WINDOW = ZOOM_LEVEL_FIT_TO_WINDOW
            """
            specifies that the video should be zoomed to window size
            """
            FIT_TO_WINDOW_FIXED_ASPECT = ZOOM_LEVEL_FIT_TO_WINDOW_FIXED_ASPECT
            """
            specifies that the video should be zoomed to window size with using a fixed aspect ratio
            """
            FULLSCREEN = ZOOM_LEVEL_FULLSCREEN
            """
            specifies that the video should be displayed in fullscreen mode, if available
            """
            NOT_AVAILABLE = ZOOM_LEVEL_NOT_AVAILABLE
            """
            specifies that the video window itself is not available at all, e.g.

            in cases of pure audio playback
            """
            ORIGINAL = ZOOM_LEVEL_ORIGINAL
            """
            specifies that the video should be displayed with its original size
            """
            ZOOM_1_TO_2 = ZOOM_LEVEL_ZOOM_1_TO_2
            """
            specifies that the video should be zoomed to a factor of 1:2
            """
            ZOOM_1_TO_4 = ZOOM_LEVEL_ZOOM_1_TO_4
            """
            specifies that the video should be zoomed to a factor of 1:4
            """
            ZOOM_2_TO_1 = ZOOM_LEVEL_ZOOM_2_TO_1
            """
            specifies that the video should be zoomed to a factor of 2:1
            """
            ZOOM_4_TO_1 = ZOOM_LEVEL_ZOOM_4_TO_1
            """
            specifies that the video should be zoomed to a factor of 4:1
            """
    else:
        # keep document generators happy
        from ...lo.media.zoom_level import ZoomLevel as ZoomLevel


__all__ = ['ZoomLevel']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
import typing
from abc import abstractproperty
from .base_index import BaseIndex as BaseIndex_8f0d0a40
if typing.TYPE_CHECKING:
    from ..container.x_index_replace import XIndexReplace as XIndexReplace_feed0dd7
    from .x_document_index_mark import XDocumentIndexMark as XDocumentIndexMark_fe490de7

class UserDefinedIndex(BaseIndex_8f0d0a40):
    """
    Service Class

    specifies service of user defined indexes within a document.

    See Also:
        `API UserDefinedIndex <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1UserDefinedIndex.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.UserDefinedIndex'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def DocumentIndexMarks(self) -> typing.Tuple[XDocumentIndexMark_fe490de7, ...]:
        """
        contains all index marks that are related to this index.
        """
        ...

    @abstractproperty
    def CreateFromEmbeddedObjects(self) -> bool:
        """
        determines if embedded objects are included in the index.
        """
        ...

    @abstractproperty
    def CreateFromGraphicObjects(self) -> bool:
        """
        determines if graphic objects are included in the index.
        """
        ...

    @abstractproperty
    def CreateFromMarks(self) -> bool:
        """
        determines if the document index marks are included in this index.
        """
        ...

    @abstractproperty
    def CreateFromTables(self) -> bool:
        """
        determines if tables are included in the index.
        """
        ...

    @abstractproperty
    def CreateFromTextFrames(self) -> bool:
        """
        determines if text frames are included in the index.
        """
        ...

    @abstractproperty
    def LevelParagraphStyles(self) -> XIndexReplace_feed0dd7:
        """
        contains the interface to access the paragraph style names that are included in this index.
        """
        ...

    @abstractproperty
    def UseLevelFromSource(self) -> bool:
        """
        determines if the outline level of the location of the indexed object is used as index level of the index entry.
        """
        ...


__all__ = ['UserDefinedIndex']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.script
from __future__ import annotations
import typing
import uno
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.x_introspection_access import XIntrospectionAccess as XIntrospectionAccess_2a050f2c

class XInvocation(XInterface_8f010a43):
    """
    gives access to an object's methods and properties.
    
    Container access is available through com.sun.star.container.XIndexContainer, com.sun.star.container.XNameContainer and com.sun.star.container.XEnumerationAccess.

    See Also:
        `API XInvocation <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1script_1_1XInvocation.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.script'
    __ooo_full_ns__: str = 'com.sun.star.script.XInvocation'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.script.XInvocation'

    @abstractmethod
    def getIntrospection(self) -> XIntrospectionAccess_2a050f2c:
        """
        returns the introspection from this object or NULL if the object does not provide this information.
        """
        ...
    @abstractmethod
    def getValue(self, aPropertyName: str) -> object:
        """
        returns the value of the property with the specified name.

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
        """
        ...
    @abstractmethod
    def hasMethod(self, aName: str) -> bool:
        """
        returns TRUE if the method with the specified name exists, else FALSE.
        
        This optimizes the calling sequence ( XInvocation.hasMethod(), XInvocation.invoke() )!
        """
        ...
    @abstractmethod
    def hasProperty(self, aName: str) -> bool:
        """
        returns TRUE if the property with the specified name exists, else FALSE.
        """
        ...
    @abstractmethod
    def invoke(self, aFunctionName: str, aParams: typing.Tuple[object, ...], aOutParamIndex: uno.ByteSequence, aOutParam: typing.Tuple[object, ...]) -> object:
        """
        provides access to methods exposed by an object.
        
        Example: aOutParamIndex == { 1, 4 } means that aOutParam[0] contains the out value of the aParams[1] parameter and aOutParam[1] contains the out value of the aParams[4] parameter.

        * ``aOutParamIndex`` is an out direction argument.
        * ``aOutParam`` is an out direction argument.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.script.CannotConvertException: ``CannotConvertException``
            com.sun.star.reflection.InvocationTargetException: ``InvocationTargetException``
        """
        ...
    @abstractmethod
    def setValue(self, aPropertyName: str, aValue: object) -> None:
        """
        sets a value to the property with the specified name.
        
        If the underlying object implements an com.sun.star.container.XNameContainer, then this method will insert the value if there is no such aPropertyName.

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
            com.sun.star.script.CannotConvertException: ``CannotConvertException``
            com.sun.star.reflection.InvocationTargetException: ``InvocationTargetException``
        """
        ...

__all__ = ['XInvocation']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart
from __future__ import annotations
import typing
from abc import abstractproperty
from .chart_data_point_properties import ChartDataPointProperties as ChartDataPointProperties_677c10bd
from .chart_statistics import ChartStatistics as ChartStatistics_e2190d37
if typing.TYPE_CHECKING:
    from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa

class ChartDataRowProperties(ChartDataPointProperties_677c10bd, ChartStatistics_e2190d37):
    """
    Service Class

    specifies the properties for a group of graphic elements which belong to a data row (also known as data series).
    
    For this service, the properties supported by ChartDataPointProperties are applied to all data point elements contained in this group. They serve as a template; thus, when changing a data point property afterwards
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API ChartDataRowProperties <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart_1_1ChartDataRowProperties.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.ChartDataRowProperties'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Axis(self) -> int:
        """
        determines to which axis the data row is assigned.
        
        The axis must be a primary or secondary y-axis
        """
        ...

    @abstractproperty
    def DataErrorProperties(self) -> XPropertySet_bc180bfa:
        """
        holds the properties of the error markers, if those are enabled.
        """
        ...

    @abstractproperty
    def DataMeanValueProperties(self) -> XPropertySet_bc180bfa:
        """
        holds the properties of the average line, if such one is enabled.
        """
        ...

    @abstractproperty
    def DataRegressionProperties(self) -> XPropertySet_bc180bfa:
        """
        holds the properties of the regression line, if such one is enabled.
        """
        ...


__all__ = ['ChartDataRowProperties']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.report
from __future__ import annotations
import typing
from abc import abstractmethod, abstractproperty
from ..document.x_document_sub_storage_supplier import XDocumentSubStorageSupplier as XDocumentSubStorageSupplier_da021351
from ..document.x_storage_based_document import XStorageBasedDocument as XStorageBasedDocument_6b1310b2
from ..document.x_view_data_supplier import XViewDataSupplier as XViewDataSupplier_2ae20f28
from ..embed.x_visual_object import XVisualObject as XVisualObject_c6c80c28
from ..frame.x_loadable import XLoadable as XLoadable_989a0a7f
from ..frame.x_model import XModel as XModel_7a6e095c
from .x_functions_supplier import XFunctionsSupplier as XFunctionsSupplier_1ee10f09
from .x_report_component import XReportComponent as XReportComponent_df0e2b
from ..style.x_style_families_supplier import XStyleFamiliesSupplier as XStyleFamiliesSupplier_4c5a1020
from ..ui.xui_configuration_manager_supplier import XUIConfigurationManagerSupplier as XUIConfigurationManagerSupplier_ab1c1243
from ..util.x_closeable import XCloseable as XCloseable_99ee0aa8
from ..util.x_modifiable2 import XModifiable2 as XModifiable2_b0320b3c
if typing.TYPE_CHECKING:
    from ..document.x_event_broadcaster import XEventBroadcaster as XEventBroadcaster_2b120f2b
    from .x_groups import XGroups as XGroups_90d00a7c
    from .x_section import XSection as XSection_9b630ad1
    from ..sdbc.x_connection import XConnection as XConnection_a36a0b0c

class XReportDefinition(XDocumentSubStorageSupplier_da021351, XStorageBasedDocument_6b1310b2, XViewDataSupplier_2ae20f28, XVisualObject_c6c80c28, XLoadable_989a0a7f, XModel_7a6e095c, XFunctionsSupplier_1ee10f09, XReportComponent_df0e2b, XStyleFamiliesSupplier_4c5a1020, XUIConfigurationManagerSupplier_ab1c1243, XCloseable_99ee0aa8, XModifiable2_b0320b3c):
    """
    identifies a XReportComponent as being a (sub-) report.
    
    This interface does not really provide an own functionality, it is only for easier runtime identification of report components.
    
    A report fulfills several tasks, like storing the structure of its report components and it provides the event environment for its contained elements.

    See Also:
        `API XReportDefinition <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1report_1_1XReportDefinition.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.report'
    __ooo_full_ns__: str = 'com.sun.star.report.XReportDefinition'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.report.XReportDefinition'

    @abstractmethod
    def getAvailableMimeTypes(self) -> typing.Tuple[str, ...]:
        """
        returns a sequence of the currently supported output formats.

        Raises:
            com.sun.star.lang.DisposedException: ``DisposedException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractmethod
    def getEventBroadcaster(self) -> XEventBroadcaster_2b120f2b:
        """
        makes it possible to register listeners which are called whenever a document event occurs.
        
        This is a workaround due to the fact that this interface can not be directly inherited from com.sun.star.document.XEventBroadcaster because the methods addEventListener and removeEventListener are already defined in com.sun.star.lang.XComponent. A queryInterface call is still supported to the com.sun.star.document.XEventBroadcaster interface.

        Raises:
            com.sun.star.lang.DisposedException: ``DisposedException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractproperty
    def ActiveConnection(self) -> XConnection_a36a0b0c:
        """
        specifies the active connection which is used to create the resulting report.
        """
        ...

    @abstractproperty
    def Caption(self) -> str:
        """
        Represents the title of the report in print preview.
        """
        ...

    @abstractproperty
    def Command(self) -> str:
        """
        is the command which should be executed, the type of command depends on the CommandType.
        
        In case of a CommandType of CommandType.COMMAND, means in case the Command specifies an SQL statement, the inherited com.sun.star.sdbc.RowSet.EscapeProcessing becomes relevant:It then can be to used to specify whether the SQL statement should be analyzed on the client side before sending it to the database server.The default value for com.sun.star.sdbc.RowSet.EscapeProcessing is TRUE. By switching it to FALSE, you can pass backend-specific SQL statements, which are not standard SQL, to your database.
        """
        ...

    @abstractproperty
    def CommandType(self) -> int:
        """
        specifies the type of the command to be executed to retrieve a result set.
        
        Command needs to be interpreted depending on the value of this property.
        
        This property is only meaningful together with the Command property, thus either both or none of them are present.
        """
        ...

    @abstractproperty
    def DataSourceName(self) -> str:
        """
        is the name of the datasource to use, this could be a named datasource or the URL of a data access component.
        """
        ...

    @abstractproperty
    def Detail(self) -> XSection_9b630ad1:
        """
        returns the detail section.
        """
        ...

    @abstractproperty
    def EscapeProcessing(self) -> bool:
        """
        specifies if the Command should be analyzed on the client side before sending it to the database server.
        
        The default value of this property is TRUE. By switching it to FALSE, you can pass backend-specific SQL statements, which are not standard SQL, to your database.
        
        This property is usually present together with the Command and CommandType properties, and is evaluated if and only if CommandType equals CommandType.COMMAND.
        """
        ...

    @abstractproperty
    def Filter(self) -> str:
        """
        specifies an additional filter to optionally use.
        
        The Filter string has to form a SQL WHERE-clause, without the WHERE-string itself.
        
        If a DataSourceName, Command and CommandType are specified, a RowSet can be created with this information. If the results provided by the row set are to be additionally filtered, the Filter property can be used.
        
        Note that the Filter property does not make sense if a ResultSet has been specified in the DataAccessDescriptor.
        """
        ...

    @abstractproperty
    def GroupKeepTogether(self) -> int:
        """
        Specifies whether groups in a multi column report are kept together.
        """
        ...

    @abstractproperty
    def Groups(self) -> XGroups_90d00a7c:
        """
        Represents the groups of the report.
        """
        ...

    @abstractproperty
    def MimeType(self) -> str:
        """
        Represents the output format (media (mime) type) of the resulting document when executing this report.
        """
        ...

    @abstractproperty
    def PageFooter(self) -> XSection_9b630ad1:
        """
        returns the page footer if the PageFooterOn is TRUE.
        """
        ...

    @abstractproperty
    def PageFooterOn(self) -> bool:
        """
        Defines that the page footer is on.
        
        Default is TRUE.
        """
        ...

    @abstractproperty
    def PageFooterOption(self) -> int:
        """
        Represents the location of the page footer.
        """
        ...

    @abstractproperty
    def PageHeader(self) -> XSection_9b630ad1:
        """
        returns the page header if the PageHeaderOn is TRUE.
        """
        ...

    @abstractproperty
    def PageHeaderOn(self) -> bool:
        """
        Defines that the page header is on.
        
        Default is TRUE.
        """
        ...

    @abstractproperty
    def PageHeaderOption(self) -> int:
        """
        Represents the location of the page header.
        """
        ...

    @abstractproperty
    def ReportFooter(self) -> XSection_9b630ad1:
        """
        returns the report footer if the ReportFooterOn is TRUE.
        """
        ...

    @abstractproperty
    def ReportFooterOn(self) -> bool:
        """
        Defines that the report footer is on.
        
        Default is FALSE.
        """
        ...

    @abstractproperty
    def ReportHeader(self) -> XSection_9b630ad1:
        """
        returns the report header if the ReportHeaderOn is TRUE.
        """
        ...

    @abstractproperty
    def ReportHeaderOn(self) -> bool:
        """
        Defines that the report header is on.
        
        Default is FALSE.
        """
        ...


__all__ = ['XReportDefinition']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.sheet.ValidationAlertStyle import ValidationAlertStyleProto

class ValidationAlertStyle(Enum):
    """
    Enum Class


    See Also:
        `API ValidationAlertStyle <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet.html#aecf58149730f4c8c5c18c70f3c7c5db7>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.ValidationAlertStyle'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.sheet.ValidationAlertStyle'

    INFO = cast("ValidationAlertStyleProto", 'INFO')
    """
    information message is shown and the user is asked whether the change will be accepted (defaulted to \"Yes\").
    """
    MACRO = cast("ValidationAlertStyleProto", 'MACRO')
    """
    macro is executed.
    """
    STOP = cast("ValidationAlertStyleProto", 'STOP')
    """
    error message is shown and the change is rejected.
    """
    WARNING = cast("ValidationAlertStyleProto", 'WARNING')
    """
    warning message is shown and the user is asked whether the change will be accepted (defaulted to \"No\").
    """

__all__ = ['ValidationAlertStyle']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.beans


class PropertyAttribute(object):
    """
    Const Class

    These values are used to specify the behavior of a Property.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API PropertyAttribute <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1beans_1_1PropertyAttribute.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.beans'
    __ooo_full_ns__: str = 'com.sun.star.beans.PropertyAttribute'
    __ooo_type_name__: str = 'const'

    MAYBEVOID = 1
    """
    indicates that a property value can be void.
    
    It does not mean that the type of the property is void!
    """
    BOUND = 2
    """
    indicates that a PropertyChangeEvent will be fired to all registered XPropertyChangeListeners whenever the value of this property changes.
    """
    CONSTRAINED = 4
    """
    indicates that a PropertyChangeEvent will be fired to all registered XVetoableChangeListeners whenever the value of this property is about to change.
    """
    TRANSIENT = 8
    """
    indicates that the value of the property is not persistent.
    """
    READONLY = 16
    """
    indicates that the value of the property is read-only.
    """
    MAYBEAMBIGUOUS = 32
    """
    indicates that the value of the property can be ambiguous.
    """
    MAYBEDEFAULT = 64
    """
    indicates that the property can be set to default.
    """
    REMOVABLE = 128
    """
    indicates that the property can be removed (i.e., by calling XPropertyContainer.removeProperty()).
    """
    REMOVEABLE = 128
    OPTIONAL = 256
    """
    indicates that a property is optional.
    
    This attribute is not of interest for concrete property implementations. It's needed for property specifications inside service specifications in UNOIDL.
    
    **since**
    
        OOo 1.1.2
    """

__all__ = ['PropertyAttribute']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.script.provider
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ...uno.exception import Exception as Exception_85530a09
from ...uno.x_interface import XInterface as XInterface_8f010a43

class ScriptFrameworkErrorException(Exception_85530a09):
    """
    Exception Class

    is a checked exception that represents an error encountered by the Scripting Framework whilst executing a script

    See Also:
        `API ScriptFrameworkErrorException <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1script_1_1provider_1_1ScriptFrameworkErrorException.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.script.provider'
    __ooo_full_ns__: str = 'com.sun.star.script.provider.ScriptFrameworkErrorException'
    __ooo_type_name__: str = 'exception'
    __pyunointerface__: str = 'com.sun.star.script.provider.ScriptFrameworkErrorException'
    __pyunostruct__: str = 'com.sun.star.script.provider.ScriptFrameworkErrorException'

    typeName: str = 'com.sun.star.script.provider.ScriptFrameworkErrorException'
    """Literal Constant ``com.sun.star.script.provider.ScriptFrameworkErrorException``"""

    def __init__(self, Message: typing.Optional[str] = '', Context: typing.Optional[XInterface_8f010a43] = None, scriptName: typing.Optional[str] = '', language: typing.Optional[str] = '', errorType: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            scriptName (str, optional): scriptName value.
            language (str, optional): language value.
            errorType (int, optional): errorType value.
        """
        kargs = {
            "Message": Message,
            "Context": Context,
            "scriptName": scriptName,
            "language": language,
            "errorType": errorType,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._script_name = kwargs["scriptName"]
        self._language = kwargs["language"]
        self._error_type = kwargs["errorType"]
        inst_keys = ('scriptName', 'language', 'errorType')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)

    @property
    def scriptName(self) -> str:
        """
        Name of script where error occurred.
        """
        return self._script_name
    
    @scriptName.setter
    def scriptName(self, value: str) -> None:
        self._script_name = value

    @property
    def language(self) -> str:
        """
        Scripting language of script that generated exception.
        """
        return self._language
    
    @language.setter
    def language(self, value: str) -> None:
        self._language = value

    @property
    def errorType(self) -> int:
        """
        error type com.sun.star.script.provider.ScriptFrameworkErrorType
        """
        return self._error_type
    
    @errorType.setter
    def errorType(self, value: int) -> None:
        self._error_type = value


__all__ = ['ScriptFrameworkErrorException']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.packages
from __future__ import annotations
from ..container.x_hierarchical_name_access import XHierarchicalNameAccess as XHierarchicalNameAccess_9e2611b5
from ..lang.x_initialization import XInitialization as XInitialization_d46c0cca
from ..lang.x_single_service_factory import XSingleServiceFactory as XSingleServiceFactory_27210f0d
from ..util.x_changes_batch import XChangesBatch as XChangesBatch_bb3b0bb9

class Package(XHierarchicalNameAccess_9e2611b5, XInitialization_d46c0cca, XSingleServiceFactory_27210f0d, XChangesBatch_bb3b0bb9):
    """
    Service Class

    The Package is a service that provides access to a set of files and folders contained within a Package.
    
    One instance of the Package service exists for each Package file to be manipulated.
    
    Each instance is created with an argument which specifies the URL of the Package file to which the user requires access. If the instance is created without arguments, it must be initialized with the com.sun.star.lang.XInitialization service methods before it is a valid instance of the service.

    See Also:
        `API Package <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1packages_1_1Package.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.packages'
    __ooo_full_ns__: str = 'com.sun.star.packages.Package'
    __ooo_type_name__: str = 'service'


__all__ = ['Package']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
if typing.TYPE_CHECKING:
    from ..util.color import Color as Color_68e908c5

class SpreadsheetViewSettings(XPropertySet_bc180bfa):
    """
    Service Class

    contains settings which are specific to each view of a spreadsheet
    
    **since**
    
        LibreOffice 7.4

    See Also:
        `API SpreadsheetViewSettings <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetViewSettings.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.SpreadsheetViewSettings'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def FormulaBarHeight(self) -> int:
        """
        Number of lines shown in the Formula bar Default is 1, maximum value is 25.
        
        **since**
        
            LibreOffice 7.4
        """
        ...

    @abstractproperty
    def GridColor(self) -> Color_68e908c5:
        """
        specifies the color in which the cell grid is displayed.
        """
        ...

    @abstractproperty
    def HasColumnRowHeaders(self) -> bool:
        """
        enables the column and row headers of the view.
        """
        ...

    @abstractproperty
    def HasHorizontalScrollBar(self) -> bool:
        """
        enables the horizontal scroll bar of the view.
        """
        ...

    @abstractproperty
    def HasSheetTabs(self) -> bool:
        """
        enables the sheet tabs of the view.
        """
        ...

    @abstractproperty
    def HasVerticalScrollBar(self) -> bool:
        """
        enables the vertical scroll bar of the view.
        """
        ...

    @abstractproperty
    def HideSpellMarks(self) -> bool:
        """
        disables the display of marks from online spelling.
        """
        ...

    @abstractproperty
    def IsOutlineSymbolsSet(self) -> bool:
        """
        enables the display of outline symbols.
        """
        ...

    @abstractproperty
    def IsValueHighlightingEnabled(self) -> bool:
        """
        controls whether strings, values, and formulas are displayed in different colors.
        """
        ...

    @abstractproperty
    def ShowAnchor(self) -> bool:
        """
        enables display of anchor symbols when drawing objects are selected.
        """
        ...

    @abstractproperty
    def ShowCharts(self) -> int:
        """
        enables the display of charts in the view.
        """
        ...

    @abstractproperty
    def ShowDrawing(self) -> int:
        """
        enables the display of drawing objects in the view.
        """
        ...

    @abstractproperty
    def ShowFormulas(self) -> bool:
        """
        controls whether formulas are displayed instead of their results.
        """
        ...

    @abstractproperty
    def ShowGrid(self) -> bool:
        """
        enables the display of the cell grid.
        """
        ...

    @abstractproperty
    def ShowHelpLines(self) -> bool:
        """
        enables display of help lines when moving drawing objects.
        """
        ...

    @abstractproperty
    def ShowNotes(self) -> bool:
        """
        controls whether a marker is shown for notes in cells.
        """
        ...

    @abstractproperty
    def ShowObjects(self) -> int:
        """
        enables display of embedded objects in the view.
        """
        ...

    @abstractproperty
    def ShowPageBreaks(self) -> bool:
        """
        enables display of page breaks.
        """
        ...

    @abstractproperty
    def ShowZeroValues(self) -> bool:
        """
        enables display of zero-values.
        """
        ...

    @abstractproperty
    def ZoomType(self) -> int:
        """
        This property defines the zoom type for the document.
        """
        ...

    @abstractproperty
    def ZoomValue(self) -> int:
        """
        Defines the zoom value to use.
        
        Valid only if the ZoomType is set to com.sun.star.view.DocumentZoomType.BY_VALUE.
        """
        ...


__all__ = ['SpreadsheetViewSettings']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.dom.events
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_event import XEvent as XEvent_e0c30ce4
if typing.TYPE_CHECKING:
    from ..views.x_abstract_view import XAbstractView as XAbstractView_35f90f4a

class XUIEvent(XEvent_e0c30ce4):
    """

    See Also:
        `API XUIEvent <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1events_1_1XUIEvent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.dom.events'
    __ooo_full_ns__: str = 'com.sun.star.xml.dom.events.XUIEvent'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.dom.events.XUIEvent'

    @abstractmethod
    def getDetail(self) -> int:
        """
        """
        ...
    @abstractmethod
    def getView(self) -> XAbstractView_35f90f4a:
        """
        """
        ...
    @abstractmethod
    def initUIEvent(self, typeArg: str, canBubbleArg: bool, cancelableArg: bool, viewArg: XAbstractView_35f90f4a, detailArg: int) -> None:
        """
        """
        ...

__all__ = ['XUIEvent']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt.grid
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_sortable_mutable_grid_data_model import XSortableMutableGridDataModel as XSortableMutableGridDataModel_f6af1377
if typing.TYPE_CHECKING:
    from .x_mutable_grid_data_model import XMutableGridDataModel as XMutableGridDataModel_6387103b
    from ...i18n.x_collator import XCollator as XCollator_892a09e0

class SortableGridDataModel(XSortableMutableGridDataModel_f6af1377):
    """
    Service Class

    provides a default implementation of a XSortableGridData.
    
    This service must be created with a secondary grid data model, which all actual data requests are delegated to. But before providing this data to the service's own clients, it is sorted, according to the sort order defined via the XSortableGridData interface.
    
    The service implementation is able to compare the default scalar types, plus strings.
    
    For determining the data type of a column which the data should be sorted by, the first non-VOID data encountered in this column is taken into account. Further read requests to this column will assume that all non-VOID data is of the same type.
    
    Consequently, you cannot use this service with data sets containing heterogeneous data in a given column.
    
    All requests made via the XMutableGridDataModel are delegated to the XMutableGridDataModel instance passed in the service constructor.
    
    Note that changing the data might result in the sort order being destroyed. If you want to ensure that the data represented by the model is still sorted after your modifications, you should call XSortableGridData.sortByColumn(), again.

    See Also:
        `API SortableGridDataModel <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1grid_1_1SortableGridDataModel.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt.grid'
    __ooo_full_ns__: str = 'com.sun.star.awt.grid.SortableGridDataModel'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def create(self, DelegatorModel: XMutableGridDataModel_6387103b) -> None:
        """
        creates a new instance of the SortableGridDataModel
        
        For string comparison, a default com.sun.star.i18n.Collator, based on the system's locale, will be used.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def createWithCollator(self, DelegatorModel: XMutableGridDataModel_6387103b, Collator: XCollator_892a09e0) -> None:
        """
        creates a new instance of the ScortableDefaultGridDataModel, passing a collator to be used for string comparison.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['SortableGridDataModel']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.security
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .ext_alt_name_type import ExtAltNameType as ExtAltNameType_8c0df5


class CertAltNameEntry(object):
    """
    Struct Class

    struct contains a single entry within a Subject Alternative Name Extension of a X509 certificate.

    See Also:
        `API CertAltNameEntry <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1security_1_1CertAltNameEntry.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.security'
    __ooo_full_ns__: str = 'com.sun.star.security.CertAltNameEntry'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.security.CertAltNameEntry'
    """Literal Constant ``com.sun.star.security.CertAltNameEntry``"""

    def __init__(self, Type: typing.Optional[ExtAltNameType_8c0df5] = ExtAltNameType_8c0df5.OTHER_NAME, Value: typing.Optional[object] = None) -> None:
        """
        Constructor

        Arguments:
            Type (ExtAltNameType, optional): Type value.
            Value (object, optional): Value value.
        """
        super().__init__()

        if isinstance(Type, CertAltNameEntry):
            oth: CertAltNameEntry = Type
            self.Type = oth.Type
            self.Value = oth.Value
            return

        kargs = {
            "Type": Type,
            "Value": Value,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._type = kwargs["Type"]
        self._value = kwargs["Value"]


    @property
    def Type(self) -> ExtAltNameType_8c0df5:
        """
        defines the type of the value.
        
        With this information you can determine how to interpret the Any value.
        """
        return self._type

    @Type.setter
    def Type(self, value: ExtAltNameType_8c0df5) -> None:
        self._type = value

    @property
    def Value(self) -> object:
        """
        stores the value of entry.
        """
        return self._value

    @Value.setter
    def Value(self, value: object) -> None:
        self._value = value


__all__ = ['CertAltNameEntry']
